"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var scales_exports = {};
__export(scales_exports, {
  AXIS_TYPE: () => AXIS_TYPE,
  BandScale: () => BandScale,
  LinearScale: () => LinearScale,
  LogScale: () => LogScale,
  Scale: () => Scale,
  TimeLinearScale: () => TimeLinearScale
});
module.exports = __toCommonJS(scales_exports);
var React = __toESM(require("react"));
var import_d3 = require("d3");
const AXIS_TYPE = {
  BAND: "BAND",
  LINEAR: "LINEAR",
  DATETIME: "DATETIME",
  LOG: "LOG"
};
const getInterval = (interval) => {
  switch (interval) {
    case "DAY":
      return import_d3.utcDay;
    case "MONTH":
      return import_d3.utcMonth;
    case "WEEK":
      return import_d3.utcWeek;
    case "YEAR":
      return import_d3.utcYear;
    default:
      return null;
  }
};
class Scale {
  scale;
  type;
  constructor(scale) {
    this.type = "";
    this.scale = scale;
  }
  getBandwidth() {
    return 0;
  }
}
class BandScale extends Scale {
  type;
  scale;
  axisProps;
  constructor(scale, axisProps) {
    super(scale);
    this.scale = scale;
    this.type = "BAND";
    this.axisProps = axisProps;
  }
  get(value) {
    if (typeof value !== "string") return 0;
    return this.scale(value);
  }
  getTicks() {
    return this.scale.domain();
  }
  getTickFormatted(t) {
    if (typeof t !== "string") return t;
    if (typeof this.axisProps?.tick?.tickFormat === "function") {
      return this.axisProps?.tick?.tickFormat(t);
    }
    return t;
  }
  getTicksScaled() {
    return this.scale.domain().map((d) => (this.get(d) ?? 0) + this.getBandwidth() / 2);
  }
  getBandwidth() {
    return this.scale.bandwidth();
  }
}
class LinearScale extends Scale {
  type;
  scale;
  axisProps;
  constructor(scale, axisProps) {
    super(scale);
    this.scale = scale;
    this.type = "LINEAR";
    this.axisProps = axisProps;
  }
  get(value) {
    if (typeof value !== "number") return 0;
    return this.scale(value);
  }
  getTickFormatted(t) {
    if (typeof t !== "number") return t.toString();
    if (typeof this.axisProps?.tick?.tickFormat === "function") {
      return this.axisProps?.tick?.tickFormat(t);
    }
    if (typeof this.axisProps?.tick?.tickFormat === "string") {
      return (0, import_d3.format)(this.axisProps?.tick?.tickFormat)(t);
    }
    return t.toString();
  }
  getTicks(dimension) {
    const ticks = this.scale.ticks?.(this.axisProps?.tick?.tickCount ?? Math.ceil(dimension / 80));
    if (this.axisProps?.tick?.tickValues) {
      if (this.axisProps?.tick?.overwriteTicks) return this.axisProps?.tick?.tickValues;
      this.axisProps?.tick?.tickValues.forEach((t) => {
        if (typeof t !== "number") return;
        const isTickAlreadyPresent = ticks.find((tick) => tick === t);
        if (isTickAlreadyPresent) return;
        ticks.push(t);
      });
    }
    return ticks;
  }
  getTicksScaled(dimension) {
    const ticks = this.getTicks(dimension);
    return ticks.map((t) => typeof t === "number" ? this.get(t) : 0);
  }
}
class LogScale extends LinearScale {
  type;
  scale;
  axisProps;
  constructor(scale, axisProps) {
    super(scale, axisProps);
    this.scale = scale;
    this.type = "LOG";
    this.axisProps = axisProps;
  }
  getTickFormatted(t) {
    if (typeof t !== "number") return t.toString();
    if (typeof this.axisProps?.tick?.tickFormat === "function") {
      return this.axisProps?.tick?.tickFormat(t);
    }
    if (typeof this.axisProps?.tick?.tickFormat === "string") {
      return (0, import_d3.format)(this.axisProps?.tick?.tickFormat)(t);
    }
    return (0, import_d3.format)("~s")(t);
  }
}
class TimeLinearScale extends Scale {
  type;
  scale;
  axisProps;
  constructor(scale, axisProps) {
    super(scale);
    this.scale = scale;
    this.type = "DATETIME";
    this.axisProps = axisProps;
  }
  get(value) {
    if (typeof value !== "object") return 0;
    return this.scale(value);
  }
  getTickFormatted(t) {
    if (typeof t !== "object") return t.toString();
    if (typeof this.axisProps?.tick?.tickFormat === "function") {
      return this.axisProps?.tick?.tickFormat(t);
    }
    if (typeof this.axisProps?.tick?.tickFormat === "string") {
      return (0, import_d3.timeFormat)(this.axisProps?.tick?.tickFormat)(t);
    }
    return t.toString();
  }
  getTicks(dimension, intervalType) {
    const interval = getInterval(intervalType);
    const finalTickConfig = interval || (this.axisProps?.tick?.tickCount ?? Math.ceil(dimension / 80));
    const ticks = this.scale.ticks?.(finalTickConfig);
    const ticksValues = this.axisProps?.tick?.tickValues;
    if (ticksValues) {
      if (this.axisProps?.tick?.overwriteTicks) return ticksValues;
      const newTicks = [];
      ticks.forEach((t) => {
        if (typeof t !== "object") return;
        const exists = ticksValues.some(
          (tickValue) => typeof tickValue === "object" && tickValue.getTime() === t.getTime()
        );
        if (!exists) newTicks.push(t);
      });
      return [...newTicks, ...ticksValues];
    }
    return ticks;
  }
  getTicksScaled(dimension, intervalType) {
    const ticks = this.getTicks(dimension, intervalType);
    return ticks.map((t) => typeof t === "object" ? this.get(t) : 0);
  }
}
//# sourceMappingURL=index.js.map
