import * as React from "react";
import { jsx, jsxs } from "react/jsx-runtime";
import { Grid } from "@elliemae/ds-grid";
import { DSPopperJS } from "@elliemae/ds-popperjs";
import {
  describe,
  useGetGlobalAttributes,
  useGetXstyledProps,
  useMemoMergePropsWithDefault,
  useValidateTypescriptPropTypes
} from "@elliemae/ds-props-helpers";
import { mergeRefs } from "@elliemae/ds-system";
import React2, { useCallback, useMemo, useState } from "react";
import { COLOR_PALLET } from "../helpers/colorPallet.js";
import { DSSingleStackedBarName } from "./exported-related/index.js";
import { DSSingleStackedBarPropTypes, defaultProps } from "./react-desc-prop-types.js";
import { StyledBar, StyledMouseOverDetectionBox, StyledTooltipContainer, Wrapper } from "./styles.js";
const Bar = React2.memo((props) => {
  const [referenceElement, setReferenceElement] = useState(null);
  const [isHover, setIsHover] = useState(false);
  const { height, TooltipRenderer, datum, tabIndex, isFocused, borderRadius, bg } = props;
  const handleRefCallback = useCallback(
    (_ref) => {
      if (isFocused) {
        _ref?.focus();
      }
    },
    [isFocused]
  );
  const handleMouseEnter = useCallback(() => {
    setIsHover(true);
  }, []);
  const handleMouseLeave = useCallback(() => {
    setIsHover(false);
  }, []);
  return /* @__PURE__ */ jsxs("div", { children: [
    (isFocused || isHover) && TooltipRenderer ? /* @__PURE__ */ jsxs(DSPopperJS, { referenceElement, showPopover: true, children: [
      /* @__PURE__ */ jsx(StyledMouseOverDetectionBox, {}),
      /* @__PURE__ */ jsx(StyledTooltipContainer, { children: /* @__PURE__ */ jsx(TooltipRenderer, { datum }) })
    ] }) : null,
    /* @__PURE__ */ jsx(
      StyledBar,
      {
        onMouseEnter: handleMouseEnter,
        onMouseLeave: handleMouseLeave,
        bg,
        height,
        borderRadius,
        innerRef: mergeRefs(handleRefCallback, setReferenceElement),
        tabIndex,
        role: "img",
        "aria-label": `${datum.name} value: ${datum.data}`
      }
    )
  ] });
});
const DSSingleStackedBar = (props) => {
  const propsWithDefaults = useMemoMergePropsWithDefault(props, defaultProps);
  useValidateTypescriptPropTypes(propsWithDefaults, DSSingleStackedBarPropTypes, "DSSingleStackedBar");
  const globalAttributes = useGetGlobalAttributes(
    propsWithDefaults
  );
  const xstyledProps = useGetXstyledProps(propsWithDefaults);
  const { data, LegendRenderer, gutter, height } = propsWithDefaults;
  const [keyBarFocused, setKeyBarFocused] = useState(0);
  const [isChartFocused, setIsChartFocused] = useState(false);
  const total = useMemo(() => data.map((datum) => datum.data).reduce((acc, curr) => acc + curr, 0), [data]);
  const cols = useMemo(() => data.map((datum) => `${Math.ceil(datum.data * 100) / total}%`), [data, total]);
  const rows = useMemo(
    () => LegendRenderer !== void 0 ? [`${height}px`, "auto"] : [`${height}px`],
    [LegendRenderer, height]
  );
  const barNames = useMemo(() => data.map((datum) => datum.name), [data]);
  const getBorderRadius = useCallback(
    (index) => {
      if (index === 0) return "50px 0 0 50px";
      if (index === data.length - 1) return "0 50px 50px 0";
      return void 0;
    },
    [data.length]
  );
  const handleOnKeyDown = useCallback(
    (e) => {
      if (e.code === "ArrowRight") {
        if (barNames[keyBarFocused + 1]) {
          setKeyBarFocused(keyBarFocused + 1);
        } else {
          setKeyBarFocused(0);
        }
      }
      if (e.code === "ArrowLeft") {
        if (barNames[keyBarFocused - 1]) {
          setKeyBarFocused(keyBarFocused - 1);
        } else {
          setKeyBarFocused(barNames.length - 1);
        }
      }
    },
    [keyBarFocused, barNames]
  );
  return /* @__PURE__ */ jsx(
    Wrapper,
    {
      cols,
      gutter,
      role: "region",
      onKeyDown: handleOnKeyDown,
      tabIndex: -1,
      onFocus: () => setIsChartFocused(true),
      onBlur: (e) => e.currentTarget !== e.target && setIsChartFocused(false),
      ...xstyledProps,
      ...globalAttributes,
      children: data.map((datum, i) => /* @__PURE__ */ jsxs(Grid, { rows, children: [
        /* @__PURE__ */ jsx(
          Bar,
          {
            datum,
            isFocused: barNames[keyBarFocused] === datum.name && isChartFocused,
            borderRadius: getBorderRadius(i),
            bg: COLOR_PALLET[datum.color] ?? datum.color,
            tabIndex: i === keyBarFocused ? 0 : -1,
            ...props
          },
          datum.name
        ),
        LegendRenderer !== void 0 ? /* @__PURE__ */ jsx(LegendRenderer, { datum }, `${datum.name}-legend`) : null
      ] }))
    }
  );
};
DSSingleStackedBar.displayName = DSSingleStackedBarName;
const DSSingleStackedBarWithSchema = describe(DSSingleStackedBar);
DSSingleStackedBarWithSchema.propTypes = DSSingleStackedBarPropTypes;
export {
  DSSingleStackedBar,
  DSSingleStackedBarWithSchema
};
//# sourceMappingURL=SingleStackedBar.js.map
