import * as React from "react";
import { useCallback, useMemo } from "react";
function isLinear(scale) {
  return scale.type !== "LINEAR";
}
function isBand(scale) {
  return scale.type !== "BAND";
}
function isTime(scale) {
  return scale.type !== "DATETIME";
}
function isValueT(value) {
  return typeof value === "number" || typeof value === "string" || value instanceof Date;
}
const useGetters = ({ xAxis, isHorizontal, yAxis, xScale, yScale, y2Scale }) => {
  const getXValue = useCallback(
    (datum) => {
      if (!datum) return null;
      if (!isHorizontal) {
        if (xAxis?.cols?.[datum.position]) {
          return xAxis?.cols?.[datum.position];
        }
        if (typeof datum.value === "object") return datum.value?.x;
        return datum.position.toString();
      }
      if (typeof datum.value === "number") {
        return datum.value;
      }
      return datum.value?.x;
    },
    [isHorizontal, xAxis?.cols]
  );
  const getYValue = useCallback(
    (datum) => {
      if (!datum) return null;
      if (!isHorizontal) {
        if (typeof datum.value === "number") {
          return datum.value;
        }
        return datum.value?.y;
      }
      if (yAxis?.cols?.[datum.position]) {
        return yAxis?.cols?.[datum.position];
      }
      if (typeof datum.value === "object") return datum.value?.y;
      return datum.position.toString();
    },
    [isHorizontal, yAxis?.cols]
  );
  const getXScaleValue = useCallback(
    (datum) => {
      if (isLinear(xScale)) {
        if (isValueT(datum)) return xScale?.get(datum);
        return xScale?.get(getXValue(datum));
      }
      if (isBand(xScale)) {
        if (isValueT(datum)) return xScale?.get(datum) ?? 0;
        return xScale?.get(getXValue(datum)) ?? 0;
      }
      if (isTime(xScale)) {
        if (isValueT(datum)) return xScale?.get(datum);
        return xScale?.get(new Date(getXValue(datum)));
      }
      return 0;
    },
    [getXValue, xScale]
  );
  const getYScaleValue = useCallback(
    (datum) => {
      if (isLinear(yScale)) {
        if (isValueT(datum)) return yScale?.get(datum);
        return yScale.get(getYValue(datum));
      }
      if (isBand(yScale)) {
        if (isValueT(datum)) return yScale?.get(datum) ?? 0;
        return yScale?.get(getYValue(datum)) ?? 0;
      }
      return 0;
    },
    [getYValue, yScale]
  );
  const getY2ScaleValue = useCallback(
    (datum) => {
      if (isLinear(y2Scale)) {
        if (isValueT(datum)) return y2Scale?.get(datum);
        return y2Scale.get(getYValue(datum));
      }
      if (isBand(y2Scale)) {
        if (isValueT(datum)) return y2Scale?.get(datum) ?? 0;
        return y2Scale?.get(getYValue(datum)) ?? 0;
      }
      return 0;
    },
    [getYValue, y2Scale]
  );
  const getYValueFormatted = useCallback(
    (datum) => {
      if (!datum) return null;
      const value = getYValue(datum);
      if (typeof yAxis.tick?.tickFormat === "function") return yAxis.tick.tickFormat(value);
      return value;
    },
    [getYValue, yAxis.tick]
  );
  const getXValueFormatted = useCallback(
    (datum) => {
      if (!datum) return null;
      const value = getXValue(datum);
      if (typeof xAxis.tick?.tickFormat === "function") return xAxis.tick.tickFormat(value);
      return value;
    },
    [getXValue, xAxis.tick]
  );
  return useMemo(
    () => ({
      getYValue,
      getY2ScaleValue,
      getXValue,
      getXScaleValue,
      getYScaleValue,
      getYValueFormatted,
      getXValueFormatted
    }),
    [getYValue, getXValue, getY2ScaleValue, getXScaleValue, getYScaleValue, getYValueFormatted, getXValueFormatted]
  );
};
export {
  useGetters
};
//# sourceMappingURL=useGetters.js.map
