import * as React from "react";
import { useMemo, useEffect, useState } from "react";
import ResizeObserver from "resize-observer-polyfill";
const useResizeObserver = (ref, { offsetHeight = 0, offsetWidth = 0 } = { offsetHeight: 0, offsetWidth: 0 }) => {
  const [width, setWidth] = useState(0);
  const [height, setHeight] = useState(0);
  useEffect(() => {
    if (ref) {
      const observeTarget = ref;
      const resizeObserver = new ResizeObserver((entries) => {
        entries.forEach((entry) => {
          setWidth(Math.ceil(entry.contentRect.width + offsetWidth));
          setHeight(Math.ceil(entry.contentRect.height + offsetHeight));
        });
      });
      resizeObserver.observe(observeTarget);
      return () => {
        resizeObserver.unobserve(observeTarget);
      };
    }
    return () => {
    };
  }, [offsetHeight, offsetWidth, ref]);
  return { width, height };
};
const useInternalMargins = ({
  axisLeftRef,
  axisBottomRef,
  axisRightRef,
  leftLabel,
  leftLegend,
  rightLegend,
  topLegend,
  bottomLegend,
  rightLabel,
  bottomLabel,
  toolbarRef
}) => {
  const { height: toolbarHeight } = useResizeObserver(toolbarRef, { offsetHeight: 10 });
  const { width: axisRightWidth } = useResizeObserver(axisRightRef, { offsetWidth: 10 });
  const { height: axisBottomHeight } = useResizeObserver(axisBottomRef, { offsetHeight: 20 });
  const { width: axisLeftWidth } = useResizeObserver(axisLeftRef, { offsetWidth: 10 });
  const { height: bottomLabelHeight } = useResizeObserver(bottomLabel, { offsetHeight: 10 });
  const { width: rightLabelWidth } = useResizeObserver(rightLabel, { offsetWidth: 10 });
  const { width: leftLabelWidth, height: leftLabelHeight } = useResizeObserver(leftLabel);
  const { height: topLegendHeight } = useResizeObserver(topLegend, { offsetHeight: 20 });
  const { height: bottomLegendHeight, width: bottomLegendWidth } = useResizeObserver(bottomLegend, {
    offsetHeight: 10
  });
  const { width: rightLegendWidth, height: rightLegendHeight } = useResizeObserver(rightLegend);
  const { width: leftLegendWidth, height: leftLegendHeight } = useResizeObserver(leftLegend, { offsetWidth: 20 });
  const internalMargin = useMemo(
    () => ({
      bottom: axisBottomHeight + bottomLegendHeight + bottomLabelHeight || 10,
      top: Math.max(topLegendHeight, toolbarHeight) || 10,
      right: rightLabelWidth + axisRightWidth + rightLegendWidth || 15,
      left: axisLeftWidth + leftLabelWidth + leftLegendWidth || 10
    }),
    [
      axisBottomHeight,
      bottomLegendHeight,
      bottomLabelHeight,
      topLegendHeight,
      toolbarHeight,
      rightLabelWidth,
      axisRightWidth,
      rightLegendWidth,
      axisLeftWidth,
      leftLabelWidth,
      leftLegendWidth
    ]
  );
  return useMemo(
    () => ({
      internalMargin,
      leftLegendHeight,
      leftLegendWidth,
      axisBottomHeight,
      bottomLegendHeight,
      bottomLabelHeight,
      topLegendHeight,
      rightLabelWidth,
      axisRightWidth,
      rightLegendWidth,
      axisLeftWidth,
      leftLabelWidth,
      toolbarHeight,
      leftLabelHeight,
      rightLegendHeight,
      bottomLegendWidth
    }),
    [
      axisBottomHeight,
      toolbarHeight,
      leftLegendHeight,
      axisLeftWidth,
      axisRightWidth,
      bottomLabelHeight,
      bottomLegendHeight,
      internalMargin,
      leftLabelWidth,
      leftLegendWidth,
      rightLabelWidth,
      rightLegendWidth,
      topLegendHeight,
      leftLabelHeight,
      rightLegendHeight,
      bottomLegendWidth
    ]
  );
};
export {
  useInternalMargins
};
//# sourceMappingURL=useInternalMargins.js.map
