import * as React from "react";
import { useCallback, useContext, useMemo } from "react";
import { ChartContext } from "../ChartContext.js";
const findInCircularList = (list, from, step = 1, criteria = (item) => item !== void 0) => {
  for (let i = (from + step + list.length) % list.length; i !== from && from > -1; i = (i + step + list.length) % list.length) {
    if (list[i] && criteria(i)) {
      return i;
    }
  }
  return from;
};
const useKeyboardNavigation = () => {
  const {
    activePoint,
    setActivePoint,
    containerRef,
    xScale,
    yScale,
    lastScrollbarPosition,
    setXScrollbarPosition,
    containerRatio,
    xScrollbarPosition,
    innerWidth,
    innerHeight,
    getXScaleValue,
    getYScaleValue,
    groups,
    isZooming,
    setIsZooming,
    zoomStartingPosition,
    setZoomStartingPosition,
    setMovingPosition,
    setContainerRatio,
    currentDataWithNullValues,
    props: { xScroll, yScroll }
  } = useContext(ChartContext);
  const currentSerie = useMemo(
    () => currentDataWithNullValues.find((d) => d.name === activePoint?.serie) ?? currentDataWithNullValues[0],
    [activePoint?.serie, currentDataWithNullValues]
  );
  const currentActiveItemIndex = useMemo(
    () => currentSerie?.data.findIndex((opt) => opt.key === activePoint?.key),
    [activePoint, currentSerie]
  );
  const listMap = useMemo(
    () => currentSerie?.data.map((d) => {
      if (typeof d.value === "object") return JSON.stringify(d.value);
      return d.value?.toString();
    }) ?? [],
    [currentSerie?.data]
  );
  const handleOnFocus = useCallback(
    (e) => {
      if (containerRef === e.target && activePoint === null) {
        setActivePoint(currentSerie?.data[0]);
        setXScrollbarPosition(0);
      }
    },
    [activePoint, containerRef, currentSerie?.data, setActivePoint, setXScrollbarPosition]
  );
  const handleOnBlur = useCallback(() => {
    setTimeout(() => {
      if (!containerRef?.contains(document.activeElement)) {
        setActivePoint(null);
      }
    });
  }, [setActivePoint, containerRef]);
  const navigateSerie = useCallback(
    (step) => {
      const newValue = findInCircularList(listMap, currentActiveItemIndex, step);
      setActivePoint(currentSerie?.data[newValue]);
      if (xScroll) {
        const xValue = getXScaleValue(currentSerie?.data[newValue]);
        if (xValue === void 0) return;
        const barWidth = innerWidth / containerRatio;
        const total = innerWidth * containerRatio;
        if (total <= xValue) {
          setXScrollbarPosition((total - innerWidth) / containerRatio);
        } else if (xValue > xScrollbarPosition * containerRatio + innerWidth)
          setXScrollbarPosition((prev) => {
            const nextPosition = prev + (xValue / containerRatio - prev);
            if (nextPosition + barWidth > innerWidth) return innerWidth - barWidth;
            return nextPosition;
          });
        else if (xValue < xScrollbarPosition * containerRatio) setXScrollbarPosition(xValue / containerRatio);
      } else if (yScroll) {
        const yValue = getYScaleValue(currentSerie?.data[newValue]);
        if (yValue === void 0) return;
        const barWidth = innerHeight / containerRatio;
        const total = innerHeight * containerRatio;
        if (total <= yValue) {
          setXScrollbarPosition((total - innerHeight) / containerRatio);
        } else if (yValue > xScrollbarPosition * containerRatio + innerHeight)
          setXScrollbarPosition((prev) => {
            const nextPosition = prev + (yValue / containerRatio - prev);
            if (nextPosition + barWidth > innerHeight) return innerHeight - barWidth;
            return nextPosition;
          });
        else if (yValue < xScrollbarPosition * containerRatio) setXScrollbarPosition(yValue / containerRatio);
      }
    },
    [
      listMap,
      currentActiveItemIndex,
      setActivePoint,
      currentSerie?.data,
      xScroll,
      yScroll,
      getXScaleValue,
      innerWidth,
      containerRatio,
      xScrollbarPosition,
      setXScrollbarPosition,
      getYScaleValue,
      innerHeight
    ]
  );
  const changeSerie = useCallback(
    (step) => {
      const nextSerieIndex = findInCircularList(
        groups,
        groups.findIndex((item) => item === currentSerie.name),
        step,
        (idx) => currentDataWithNullValues[idx].data[currentActiveItemIndex].value !== null
      );
      setActivePoint(currentDataWithNullValues[nextSerieIndex].data[currentActiveItemIndex]);
    },
    [groups, setActivePoint, currentActiveItemIndex, currentSerie.name, currentDataWithNullValues]
  );
  const onInputKeyDown = useCallback(
    (e) => {
      if (!activePoint) return;
      if (e.code !== "Tab") {
        e.preventDefault();
      }
      if (["ArrowLeft", "ArrowRight"].includes(e.code)) {
        if (yScale?.type === "BAND") changeSerie(e.code === "ArrowLeft" ? -1 : 1);
        else navigateSerie(e.code === "ArrowLeft" ? -1 : 1);
      }
      if (["ArrowDown", "ArrowUp"].includes(e.code)) {
        if (yScale?.type === "BAND") navigateSerie(e.code === "ArrowDown" ? 1 : -1);
        else changeSerie(e.code === "ArrowDown" ? -1 : 1);
      }
      const { code } = e;
      const isShiftKey = ["ShiftLeft", "ShiftRight"].includes(code);
      const xScaledActivePoint = getXScaleValue(activePoint);
      if (isShiftKey && !isZooming && xScale?.type !== "BAND" && xScaledActivePoint) {
        setIsZooming(true);
        setZoomStartingPosition(xScaledActivePoint - xScrollbarPosition * containerRatio);
      }
    },
    [
      activePoint,
      changeSerie,
      containerRatio,
      getXScaleValue,
      isZooming,
      navigateSerie,
      setIsZooming,
      setZoomStartingPosition,
      xScale?.type,
      xScrollbarPosition,
      yScale?.type
    ]
  );
  const handleOnKeyUp = useCallback(
    (e) => {
      if (!activePoint) return;
      if (!isZooming && xScale?.type === "BAND") return;
      const { shiftKey, code } = e;
      const isShiftKey = ["ShiftLeft", "ShiftRight"].includes(code);
      const xScaledActivePoint = getXScaleValue(activePoint);
      if (shiftKey && ["ArrowRight", "ArrowLeft"].includes(code) && xScaledActivePoint) {
        setMovingPosition(xScaledActivePoint - xScrollbarPosition * containerRatio);
      }
      if (isShiftKey && xScaledActivePoint) {
        setIsZooming(false);
        setZoomStartingPosition(0);
        setMovingPosition(0);
        const endingPosition = xScaledActivePoint - xScrollbarPosition * containerRatio;
        const isRightDirection = zoomStartingPosition < endingPosition;
        const offsetActivePoint = findInCircularList(listMap, currentActiveItemIndex, isRightDirection ? 1 : -1);
        const offSetXScaledActivePoint = getXScaleValue(currentSerie?.data[offsetActivePoint]);
        const correctEndingPosition = offSetXScaledActivePoint ?? 0 - xScrollbarPosition * containerRatio;
        const diff = Math.abs(zoomStartingPosition - correctEndingPosition);
        if (diff <= 0) return;
        const newRatio = innerWidth / (innerWidth * containerRatio / diff) < 40 ? innerWidth / 40 : innerWidth * containerRatio / diff;
        const newPosition = lastScrollbarPosition.current + (!isRightDirection ? correctEndingPosition : zoomStartingPosition) / containerRatio;
        if (newPosition > innerWidth - innerWidth / newRatio) setXScrollbarPosition(innerWidth - innerWidth / newRatio);
        else setXScrollbarPosition(newPosition);
        setActivePoint(null);
        setTimeout(() => setActivePoint(activePoint));
        setContainerRatio(newRatio);
        lastScrollbarPosition.current = newPosition;
      }
    },
    [
      activePoint,
      containerRatio,
      currentActiveItemIndex,
      currentSerie?.data,
      getXScaleValue,
      innerWidth,
      isZooming,
      lastScrollbarPosition,
      listMap,
      setActivePoint,
      setContainerRatio,
      setIsZooming,
      setMovingPosition,
      setXScrollbarPosition,
      setZoomStartingPosition,
      xScale?.type,
      xScrollbarPosition,
      zoomStartingPosition
    ]
  );
  return useMemo(
    () => ({ handleOnKeyUp, onInputKeyDown, handleOnBlur, handleOnFocus }),
    [handleOnBlur, handleOnFocus, handleOnKeyUp, onInputKeyDown]
  );
};
export {
  findInCircularList,
  useKeyboardNavigation
};
//# sourceMappingURL=useKeyboardNavigation.js.map
