import * as React from "react";
import { stack, stackOffsetDiverging } from "d3";
const getStackedIndex = (groups, serie) => {
  if (!groups) return -1;
  for (let i = 0; i < groups.length; i += 1) {
    for (let j = 0; j < groups[i].length; j += 1) {
      if (groups[i][j] === serie) return i;
    }
  }
  return -1;
};
const getStackedData = (stackedData, serie) => {
  for (let i = 0; i < stackedData?.length; i += 1) {
    const data = stackedData[i].find((d) => d.key === serie.name);
    if (data) return data;
  }
  return false;
};
const checkSharedScale = (series, isHorizontal) => {
  const scales = series.map((serie) => serie.scale || (isHorizontal ? "x" : "y")).filter((value, index, self) => self.indexOf(value) === index);
  if (scales.length > 1) {
    return false;
  }
  return scales[0];
};
const stackData = (groupsStacked, series, hiddenSeries, isHorizontal) => {
  const allSeriesStackedByGroups = [];
  const scalesStackedDataMap = [];
  if (!groupsStacked) return { stackedData: allSeriesStackedByGroups, scalesStackedDataMap };
  groupsStacked?.forEach((g) => {
    const seriesFilteredByStackGroup = series.filter(
      (serie) => g.includes(serie.name) && !hiddenSeries.includes(serie.name)
    );
    const sharedScale = checkSharedScale(seriesFilteredByStackGroup, isHorizontal);
    if (!sharedScale) return;
    scalesStackedDataMap.push(sharedScale);
    const keys = seriesFilteredByStackGroup.map((serie) => serie.name);
    const stackedData = [];
    seriesFilteredByStackGroup.forEach((serie) => {
      serie.data.forEach((d, i) => {
        stackedData[i] = {
          ...stackedData[i],
          [serie.name]: typeof d === "number" ? d : d?.y || 0
        };
      });
    });
    allSeriesStackedByGroups.push(stack().offset(stackOffsetDiverging).keys(keys)(stackedData));
  });
  return { stackedData: allSeriesStackedByGroups, scalesStackedDataMap };
};
export {
  getStackedData,
  getStackedIndex,
  stackData
};
//# sourceMappingURL=index.js.map
