import * as React from "react";
import { useCallback, useContext, useMemo } from "react";
import { ChartContext } from "../ChartContext.js";
const useUniqueData = () => {
  const {
    currentData: data,
    xScale,
    xScrollbarPosition,
    containerRatio,
    innerWidth,
    getXValue,
    getYValue,
    getXScaleValue
  } = useContext(ChartContext);
  const compare = useCallback((a, b) => {
    if (a.xPosition < b.xPosition) {
      return -1;
    }
    if (a.xPosition > b.xPosition) {
      return 1;
    }
    return 0;
  }, []);
  const isBandAxis = xScale?.type === "BAND";
  return useMemo(() => {
    let valueToPositionPerSeries = [];
    if (isBandAxis) {
      valueToPositionPerSeries = data.map(
        (serie) => serie.data.filter((datum) => {
          const xScaleValue = getXScaleValue(datum);
          if (xScaleValue === void 0) return false;
          return xScaleValue >= xScrollbarPosition * (containerRatio ?? 1) && xScaleValue <= xScrollbarPosition * (containerRatio ?? 1) + innerWidth;
        }).map((datum) => {
          const x = getXValue(datum);
          const y = getYValue(datum);
          const xScaleValue = getXScaleValue(datum);
          return {
            position: xScaleValue,
            name: serie.name,
            xValue: x,
            yValue: y,
            key: datum.position,
            datum,
            color: serie.color
          };
        })
      ).flat(1);
    } else {
      valueToPositionPerSeries = data.map(
        (serie) => serie.data.filter((datum) => {
          const xScaleValue = getXScaleValue(datum);
          if (xScaleValue === void 0) return false;
          return xScaleValue >= xScrollbarPosition * (containerRatio ?? 1) && xScaleValue <= xScrollbarPosition * (containerRatio ?? 1) + innerWidth;
        }).map((datum) => {
          const xScaleValue = getXScaleValue(datum);
          const x = getXValue(datum);
          return {
            position: xScaleValue,
            name: serie.name,
            xValue: x,
            yValue: typeof datum.value === "number" ? datum.value : datum.value.y,
            key: datum.position,
            datum,
            color: serie.color
          };
        })
      ).flat(1);
    }
    const positionUniqueData = {};
    valueToPositionPerSeries.forEach((set) => {
      if (!set.position) return;
      if (positionUniqueData[set.position]) {
        positionUniqueData[set.position] = [...positionUniqueData[set.position], { ...set }];
      } else {
        positionUniqueData[set.position] = [{ ...set }];
      }
    });
    const positionUniqueDataArray = Object.keys(positionUniqueData).map((key) => {
      const xPosition = parseFloat(key);
      const dataPerPosition = positionUniqueData[xPosition];
      return { xPosition, dataPerPosition, xValue: dataPerPosition[0].xValue };
    });
    if (isBandAxis) {
      return positionUniqueDataArray;
    }
    return positionUniqueDataArray.sort(compare).map((line, i, array) => {
      const prevPoint = array[i - 1]?.xPosition ?? 0;
      const postPoint = array[i + 1]?.xPosition ?? 0;
      const rectDetector = {
        left: (line.xPosition - prevPoint) / 2,
        right: Math.abs((postPoint === 0 ? 0 : postPoint - line.xPosition) / 2)
      };
      return { ...line, rectDetector };
    });
  }, [isBandAxis, compare, data, getXScaleValue, xScrollbarPosition, containerRatio, innerWidth, getXValue, getYValue]);
};
export {
  useUniqueData
};
//# sourceMappingURL=useUniqueData.js.map
