import * as React from "react";
import { useContext, useMemo } from "react";
import { ChartContext } from "../ChartContext.js";
const useVirtualizedSeries = () => {
  const {
    containerRatio,
    innerWidth,
    xScrollbarPosition,
    yScale,
    getXScaleValue,
    getYScaleValue,
    innerHeight,
    currentData: data,
    props: { xScroll, yScroll }
  } = useContext(ChartContext);
  return useMemo(() => {
    if (xScroll) {
      return data.map((serie) => ({
        ...serie,
        data: serie.data.filter((datum) => {
          const xScaleValue = getXScaleValue(datum);
          if (xScaleValue === void 0) return false;
          return xScaleValue >= xScrollbarPosition * (containerRatio ?? 1) - innerWidth && xScaleValue <= xScrollbarPosition * (containerRatio ?? 1) + innerWidth * 2;
        })
      }));
    }
    if (yScroll) {
      return data.map((serie) => ({
        ...serie,
        data: serie.data.filter((datum) => {
          const yScaleValue = getYScaleValue(datum);
          const offset = yScale?.getBandwidth() ?? 20;
          if (yScaleValue === void 0) return false;
          return yScaleValue > xScrollbarPosition * (containerRatio ?? 1) - offset && yScaleValue < xScrollbarPosition * (containerRatio ?? 1) + innerHeight;
        })
      }));
    }
    return data;
  }, [
    containerRatio,
    data,
    getXScaleValue,
    getYScaleValue,
    innerHeight,
    innerWidth,
    xScroll,
    xScrollbarPosition,
    yScale,
    yScroll
  ]);
};
export {
  useVirtualizedSeries
};
//# sourceMappingURL=useVirtualizedSeries.js.map
