import * as React from "react";
import { jsx } from "react/jsx-runtime";
import React2, { useContext, useMemo, useCallback } from "react";
import { ChartContext } from "../../ChartContext.js";
import { Axis } from "./Axis.js";
import { Tick } from "./Tick.js";
import { GridLine } from "./GridLine.js";
import { COLOR_PALLET } from "../../helpers/colorPallet.js";
const AxisBottom = React2.memo(() => {
  const {
    props: { xAxis, xScroll },
    innerHeight,
    xScale,
    innerWidth,
    containerRatio,
    setAxisBottomRef
  } = useContext(ChartContext);
  const realInnerWidth = useMemo(
    () => innerWidth * (xScroll ? containerRatio : 1),
    [containerRatio, innerWidth, xScroll]
  );
  const { tickRotation } = xAxis.tick || {};
  const { showGrid, intervalType } = xAxis;
  const textProps = useMemo(() => {
    const commomProps = { fill: COLOR_PALLET[xAxis?.tick?.color] || xAxis?.tick?.color };
    if (!tickRotation) return { ...commomProps, y: 17 };
    return {
      ...commomProps,
      dx: 8 * Math.sin(Math.PI * (tickRotation / 180)),
      dy: ".71em",
      y: Math.ceil(11.5 - 2.5 * (tickRotation / 15) * (tickRotation > 0 ? 1 : -1)),
      transform: `rotate(${tickRotation})`
    };
  }, [tickRotation, xAxis?.tick?.color]);
  const style = useMemo(() => {
    if (!tickRotation) return { textAnchor: "middle" };
    return { textAnchor: tickRotation > 0 ? "start" : "end" };
  }, [tickRotation]);
  const GridRenderer = useCallback(
    (props) => {
      if (!showGrid) return null;
      const { position, tickValue, ...rest } = props;
      const gridLineCoords = {
        x1: position,
        x2: position,
        y1: 0,
        y2: innerHeight
      };
      const tickFormatted = xScale?.getTickFormatted(tickValue);
      if (tickFormatted === "") return null;
      return /* @__PURE__ */ jsx(GridLine, { ...gridLineCoords, ...rest });
    },
    [innerHeight, showGrid, xScale]
  );
  const TickRenderer = useCallback(
    (props) => {
      const { position, tickValue, ...rest } = props;
      const tickLineCoords = {
        y2: 5,
        stroke: COLOR_PALLET[xAxis?.tick?.color] || xAxis?.tick?.color
      };
      const tickFormatted = xScale?.getTickFormatted(tickValue);
      if (tickFormatted === "") return null;
      return /* @__PURE__ */ jsx(
        Tick,
        {
          ...tickLineCoords,
          tickValue: tickFormatted,
          xTranslate: position,
          yTranslate: innerHeight,
          textProps,
          textStyle: style,
          ...rest
        }
      );
    },
    [xAxis?.tick?.color, xScale, innerHeight, textProps, style]
  );
  const axisColor = useMemo(() => COLOR_PALLET[xAxis.color] || xAxis.color, [xAxis.color]);
  return useMemo(() => {
    if (xAxis.hideAxis) return null;
    const lineCoords = {
      x1: 0,
      x2: realInnerWidth,
      y1: innerHeight,
      y2: innerHeight
    };
    return /* @__PURE__ */ jsx(
      Axis,
      {
        lineCoords,
        scale: xScale,
        innerRef: setAxisBottomRef,
        dimension: realInnerWidth,
        TickRenderer,
        GridRenderer,
        color: axisColor,
        intervalType
      }
    );
  }, [
    GridRenderer,
    TickRenderer,
    intervalType,
    axisColor,
    innerHeight,
    realInnerWidth,
    setAxisBottomRef,
    xAxis.hideAxis,
    xScale
  ]);
});
export {
  AxisBottom
};
//# sourceMappingURL=AxisBottom.js.map
