import * as React from "react";
import { jsx } from "react/jsx-runtime";
import React2, { useCallback, useContext, useMemo } from "react";
import { ChartContext } from "../../ChartContext.js";
import { Axis } from "./Axis.js";
import { Tick } from "./Tick.js";
import { GridLine } from "./GridLine.js";
import { COLOR_PALLET } from "../../helpers/colorPallet.js";
const AxisLeft = React2.memo(() => {
  const {
    props: { yAxis, yScroll },
    innerHeight,
    height,
    yScale,
    innerWidth,
    containerRatio,
    setAxisLeftRef
  } = useContext(ChartContext);
  const { tickRotation } = yAxis.tick || {};
  const { showGrid, intervalType } = yAxis;
  const realInnerHeight = useMemo(
    () => innerHeight * (yScroll ? containerRatio : 1),
    [containerRatio, innerHeight, yScroll]
  );
  const textProps = useMemo(() => {
    const commomProps = { fill: COLOR_PALLET[yAxis?.tick?.color] || yAxis?.tick?.color };
    if (!tickRotation) return { ...commomProps, x: -10, dy: "0.32em" };
    return {
      ...commomProps,
      dy: ".30em",
      dx: "-.10em",
      x: Math.trunc(-(11.5 - 2.5 * (tickRotation / 15) * (tickRotation > 0 ? 1 : -1))),
      transform: `rotate(${tickRotation})`
    };
  }, [tickRotation, yAxis?.tick?.color]);
  const style = useMemo(
    () => ({
      textAnchor: "end"
    }),
    []
  );
  const GridRenderer = useCallback(
    (props) => {
      if (!showGrid) return null;
      const { position, tickValue, ...rest } = props;
      const gridLineCoords = {
        x1: 0,
        x2: innerWidth,
        y1: position,
        y2: position
      };
      const tickFormatted = yScale?.getTickFormatted(tickValue);
      if (tickFormatted === "") return null;
      return /* @__PURE__ */ jsx(GridLine, { ...gridLineCoords, ...rest });
    },
    [showGrid, innerWidth, yScale]
  );
  const TickRenderer = useCallback(
    (props) => {
      const { position, tickValue, ...rest } = props;
      const tickLineCoords = {
        x2: -5,
        stroke: COLOR_PALLET[yAxis?.tick?.color] || yAxis?.tick?.color
      };
      const tickFormatted = yScale?.getTickFormatted(tickValue);
      if (tickFormatted === "") return null;
      return /* @__PURE__ */ jsx(
        Tick,
        {
          ...tickLineCoords,
          xTranslate: 0,
          yTranslate: position,
          textProps,
          textStyle: style,
          tickValue: tickFormatted,
          ...rest
        }
      );
    },
    [style, textProps, yAxis?.tick?.color, yScale]
  );
  const axisColor = useMemo(() => COLOR_PALLET[yAxis.color] || yAxis.color, [yAxis.color]);
  return useMemo(() => {
    if (yAxis.hideAxis) return null;
    const lineCoords = {
      x1: 0,
      x2: 0,
      y1: 0,
      y2: realInnerHeight
    };
    return /* @__PURE__ */ jsx(
      Axis,
      {
        lineCoords,
        scale: yScale,
        innerRef: setAxisLeftRef,
        dimension: height,
        GridRenderer,
        TickRenderer,
        color: axisColor,
        intervalType
      }
    );
  }, [
    GridRenderer,
    intervalType,
    TickRenderer,
    axisColor,
    height,
    realInnerHeight,
    setAxisLeftRef,
    yAxis.hideAxis,
    yScale
  ]);
});
export {
  AxisLeft
};
//# sourceMappingURL=AxisLeft.js.map
