import * as React from "react";
import { jsx } from "react/jsx-runtime";
import React2, { useCallback, useContext, useMemo } from "react";
import { ChartContext } from "../../ChartContext.js";
import { Axis } from "./Axis.js";
import { Tick } from "./Tick.js";
import { GridLine } from "./GridLine.js";
import { COLOR_PALLET } from "../../helpers/colorPallet.js";
const AxisRight = React2.memo(() => {
  const {
    props: { y2Axis },
    innerHeight,
    y2Scale,
    innerWidth,
    setAxisRightRef
  } = useContext(ChartContext);
  const { tickRotation } = y2Axis?.tick || {};
  const { showGrid, intervalType } = y2Axis || {};
  const textProps = useMemo(() => {
    const commomProps = { fill: COLOR_PALLET[y2Axis?.tick?.color] || y2Axis?.tick?.color };
    if (!tickRotation) return { ...commomProps, x: 10, dy: "0.32em" };
    return {
      ...commomProps,
      dx: 8 * Math.sin(Math.PI * (tickRotation / 180)),
      dy: ".71em",
      y: 11.5 - 2.5 * (tickRotation / 15) * (tickRotation > 0 ? 1 : -1),
      transform: `rotate(${tickRotation})`
    };
  }, [tickRotation, y2Axis?.tick?.color]);
  const style = useMemo(() => {
    if (!tickRotation)
      return {
        textAnchor: "start"
      };
    return { textAnchor: tickRotation > 0 ? "start" : "end" };
  }, [tickRotation]);
  const GridRenderer = useCallback(
    (props) => {
      if (!showGrid) return null;
      const { position, tickValue, ...rest } = props;
      const gridLineCoords = {
        x1: 0,
        x2: innerWidth,
        y1: position,
        y2: position
      };
      const tickFormatted = y2Scale?.getTickFormatted(tickValue);
      if (tickFormatted === "") return null;
      return /* @__PURE__ */ jsx(GridLine, { ...gridLineCoords, ...rest });
    },
    [innerWidth, showGrid, y2Scale]
  );
  const TickRenderer = useCallback(
    (props) => {
      const { position, tickValue, ...rest } = props;
      const tickLineCoords = {
        x2: 5,
        stroke: COLOR_PALLET[y2Axis?.tick?.color] || y2Axis?.tick?.color
      };
      const tickFormatted = y2Scale?.getTickFormatted(tickValue);
      if (tickFormatted === "") return null;
      return /* @__PURE__ */ jsx(
        Tick,
        {
          ...tickLineCoords,
          yTranslate: position,
          xTranslate: innerWidth,
          textProps,
          textStyle: style,
          tickValue: tickFormatted,
          ...rest
        }
      );
    },
    [innerWidth, style, textProps, y2Axis?.tick?.color, y2Scale]
  );
  const axisColor = useMemo(
    () => COLOR_PALLET[y2Axis?.color] || y2Axis?.color,
    [y2Axis?.color]
  );
  return useMemo(() => {
    if (y2Axis?.hideAxis) return null;
    const lineCoords = {
      x1: innerWidth,
      x2: innerWidth,
      y1: 0,
      y2: innerHeight
    };
    return /* @__PURE__ */ jsx(
      Axis,
      {
        lineCoords,
        scale: y2Scale,
        innerRef: setAxisRightRef,
        dimension: innerHeight,
        GridRenderer,
        TickRenderer,
        color: axisColor,
        intervalType
      }
    );
  }, [
    GridRenderer,
    intervalType,
    TickRenderer,
    axisColor,
    innerHeight,
    innerWidth,
    setAxisRightRef,
    y2Axis?.hideAxis,
    y2Scale
  ]);
});
export {
  AxisRight
};
//# sourceMappingURL=AxisRight.js.map
