import * as React from "react";
import { Fragment, jsx, jsxs } from "react/jsx-runtime";
import { useCallback, useContext, useMemo } from "react";
import { ChartContext } from "../ChartContext.js";
import { useKeyboardNavigation } from "../config/useKeyboardNavigation.js";
import { StyledSVGWrapper } from "../styles.js";
import { AxisBottom } from "./Axis/AxisBottom.js";
import { AxisLeft } from "./Axis/AxisLeft.js";
import { AxisRight } from "./Axis/AxisRight.js";
import { ClipPaths } from "./ClipPaths.js";
import { Labels } from "./Labels/index.js";
import { Legend } from "./Legend/Legend.js";
import { Scrapper } from "./Scrapper/Scrapper.js";
import { VerticalScrapper } from "./Scrapper/VerticalScrapper.js";
import { BlurMask } from "./Scroller/BlurMask.js";
import { Controllers } from "./Scroller/Controllers.js";
import { ScrollableContainerX } from "./Scroller/ScrollableContainerX.js";
import { ScrollableContainerY } from "./Scroller/ScrollableContainerY.js";
import { SeriesFactory } from "./SeriesFactory.js";
const ChartContainer = () => {
  const {
    props: { y2Axis, yScroll, xScroll, scrapper, width: userWidth },
    activePoint,
    internalMargin,
    setScrapperPosY,
    setScrapperPosX,
    setContainerRef,
    isGrabbed,
    setIsGrabbed,
    startPosition,
    innerWidth,
    innerHeight,
    setActivePoint,
    setXScrollbarPosition,
    xScrollbarPosition,
    containerRatio,
    lastScrollbarPosition,
    setIsScrollbarVisible,
    currentData,
    width,
    height
  } = useContext(ChartContext);
  const { onInputKeyDown, handleOnKeyUp, handleOnBlur, handleOnFocus } = useKeyboardNavigation();
  const onMouseEnterHandler = useCallback(() => {
    setIsScrollbarVisible(true);
    setActivePoint(null);
  }, [setActivePoint, setIsScrollbarVisible]);
  const onMouseLeaveHandler = useCallback(() => {
    setScrapperPosY(-1);
    setScrapperPosX(-1);
    setIsScrollbarVisible(false);
    setIsGrabbed(false);
  }, [setIsGrabbed, setIsScrollbarVisible, setScrapperPosX, setScrapperPosY]);
  const handleMouseMove = useCallback(
    (e) => {
      if (!isGrabbed) return;
      e.preventDefault();
      const { clientX } = e;
      const { clientY } = e;
      setActivePoint(null);
      if (xScroll) {
        const newPosition = lastScrollbarPosition.current + clientX - startPosition;
        if (newPosition < 0) setXScrollbarPosition(0);
        else if (newPosition > innerWidth - innerWidth / containerRatio)
          setXScrollbarPosition(innerWidth - innerWidth / containerRatio);
        else setXScrollbarPosition(newPosition);
      }
      if (yScroll) {
        const newPosition = lastScrollbarPosition.current + clientY - startPosition;
        if (newPosition < 0) setXScrollbarPosition(0);
        else if (newPosition > innerHeight - innerHeight / containerRatio)
          setXScrollbarPosition(innerHeight - innerHeight / containerRatio);
        else setXScrollbarPosition(newPosition);
      }
    },
    [
      isGrabbed,
      setActivePoint,
      xScroll,
      yScroll,
      lastScrollbarPosition,
      startPosition,
      setXScrollbarPosition,
      innerWidth,
      containerRatio,
      innerHeight
    ]
  );
  const handleMouseUp = useCallback(() => {
    lastScrollbarPosition.current = xScrollbarPosition;
    setIsGrabbed(false);
  }, [lastScrollbarPosition, setIsGrabbed, xScrollbarPosition]);
  const render = useMemo(() => {
    if (currentData.length === 0) return null;
    if (xScroll) {
      return /* @__PURE__ */ jsxs(Fragment, { children: [
        y2Axis ? /* @__PURE__ */ jsx(AxisRight, {}) : null,
        /* @__PURE__ */ jsx(AxisLeft, {}),
        /* @__PURE__ */ jsx(ScrollableContainerX, {})
      ] });
    }
    if (yScroll) {
      return /* @__PURE__ */ jsxs(Fragment, { children: [
        y2Axis ? /* @__PURE__ */ jsx(AxisRight, {}) : null,
        /* @__PURE__ */ jsx(AxisBottom, {}),
        /* @__PURE__ */ jsx(ScrollableContainerY, {})
      ] });
    }
    return /* @__PURE__ */ jsxs(Fragment, { children: [
      y2Axis ? /* @__PURE__ */ jsx(AxisRight, {}) : null,
      /* @__PURE__ */ jsx(AxisLeft, {}),
      /* @__PURE__ */ jsx(AxisBottom, {}),
      /* @__PURE__ */ jsx(SeriesFactory, {}),
      scrapper?.type === "horizontal" ? /* @__PURE__ */ jsx(Scrapper, {}) : null,
      scrapper?.type === "vertical" ? /* @__PURE__ */ jsx(VerticalScrapper, {}) : null
    ] });
  }, [currentData.length, scrapper?.type, xScroll, y2Axis, yScroll]);
  return /* @__PURE__ */ jsx(
    StyledSVGWrapper,
    {
      innerRef: setContainerRef,
      onKeyDown: onInputKeyDown,
      onKeyUp: handleOnKeyUp,
      tabIndex: activePoint ? -1 : 0,
      onBlur: handleOnBlur,
      onFocus: handleOnFocus,
      onMouseEnter: onMouseEnterHandler,
      onMouseLeave: onMouseLeaveHandler,
      onMouseMove: handleMouseMove,
      onMouseUp: handleMouseUp,
      onMouseDown: (e) => e.preventDefault(),
      isGrabbed,
      style: { width: userWidth, height },
      children: width !== 0 ? /* @__PURE__ */ jsxs("svg", { width, height, children: [
        /* @__PURE__ */ jsx(ClipPaths, {}),
        /* @__PURE__ */ jsx(BlurMask, {}),
        /* @__PURE__ */ jsxs("g", { children: [
          /* @__PURE__ */ jsxs("g", { children: [
            /* @__PURE__ */ jsx(Controllers, {}),
            /* @__PURE__ */ jsx(Legend, {}),
            /* @__PURE__ */ jsx(Labels, {})
          ] }),
          /* @__PURE__ */ jsx("g", { className: "container", transform: `translate(${internalMargin.left},${internalMargin.top})`, children: render })
        ] })
      ] }) : null
    }
  );
};
export {
  ChartContainer
};
//# sourceMappingURL=ChartContainer.js.map
