import * as React from "react";
import { jsx } from "react/jsx-runtime";
import { useContext, useMemo, useEffect, useState } from "react";
import { select } from "d3";
import { ChartContext } from "../../ChartContext.js";
import { LegendItem } from "./LegendItem.js";
const BottomLegend = () => {
  const {
    colorScale,
    bottomLegendWidth,
    bottomLegend,
    axisBottomHeight,
    axisLeftWidth,
    innerWidth,
    innerHeight,
    bottomLabelHeight,
    internalMargin,
    currentData,
    width: graphWidth,
    setBottomLegend
  } = useContext(ChartContext);
  const [xTransform, setXTransform] = useState(0);
  useEffect(() => {
    if (!bottomLegend) return;
    const cells = select(bottomLegend).selectAll(".cell");
    const padding = 25;
    let offset = 0;
    let verticalOffset = 0;
    currentData.forEach((_, i) => {
      if (cells.nodes()[i - 1]) {
        const lastCell = select(cells.nodes()[i - 1]);
        const d3sel = select(cells.nodes()[i]);
        const { width: currentCellWidth } = d3sel.node()?.getBBox() ?? { width: 0 };
        const lastCellWidth = lastCell.node()?.getBBox()?.width || 0;
        if (offset + lastCellWidth + padding + currentCellWidth + 10 > graphWidth) {
          offset = 0;
          verticalOffset += 20;
        } else {
          offset += lastCellWidth + padding;
        }
        d3sel.attr("transform", `translate(${offset}, ${verticalOffset})`);
      }
    });
    setXTransform(innerWidth / 2 + internalMargin.left - bottomLegendWidth / 2);
  }, [bottomLegend, currentData, bottomLegendWidth, axisLeftWidth, innerWidth, internalMargin.left, graphWidth]);
  return useMemo(
    () => /* @__PURE__ */ jsx(
      "g",
      {
        ref: setBottomLegend,
        transform: `translate(${xTransform}, ${innerHeight + bottomLabelHeight + axisBottomHeight + internalMargin.top})`,
        className: "bottom-legend",
        children: colorScale.domain().map((domainValue) => /* @__PURE__ */ jsx(LegendItem, { domainValue }, domainValue))
      }
    ),
    [axisBottomHeight, bottomLabelHeight, colorScale, innerHeight, internalMargin.top, setBottomLegend, xTransform]
  );
};
export {
  BottomLegend
};
//# sourceMappingURL=BottomLegend.js.map
