import * as React from "react";
import { jsx, jsxs } from "react/jsx-runtime";
import { useContext, useMemo, useCallback } from "react";
import { LINE } from "../../../constants.js";
import { ChartContext } from "../../ChartContext.js";
const LegendItemCircle = (props) => /* @__PURE__ */ jsx("circle", { r: 6, ...props });
const LegendItemSquare = (props) => /* @__PURE__ */ jsx("rect", { x: -6, y: -6, width: 12, height: 12, ...props });
const LegendItemDiamond = (props) => /* @__PURE__ */ jsx("g", { transform: "rotate(45)", children: /* @__PURE__ */ jsx("rect", { x: -6, y: -6, width: 12, height: 12, ...props }) });
const LegendItemsMap = {
  [LINE.POINT_STYLE.CIRCLE]: LegendItemCircle,
  [LINE.POINT_STYLE.SQUARE]: LegendItemSquare,
  [LINE.POINT_STYLE.DIAMOND]: LegendItemDiamond
};
const LegendItem = (props) => {
  const {
    colorScale,
    setHiddenSeries,
    hiddenSeries,
    originalSeries: series,
    props: { types, legend }
  } = useContext(ChartContext);
  const { domainValue } = props;
  const serieData = series.find((serie) => serie.name === domainValue);
  const LegendIcon = LegendItemsMap[serieData?.pointStyle ?? "circle"] ?? (serieData?.type === "line" || types === "scatter" ? LegendItemCircle : LegendItemSquare);
  const handleOnClick = useCallback(() => {
    if (legend?.preventFilterAction) return;
    setHiddenSeries((prev) => {
      if (prev.includes(domainValue)) return prev.filter((serie) => serie !== domainValue);
      if (prev.length + 1 !== series.length) return [...prev, domainValue];
      return prev;
    });
  }, [domainValue, legend?.preventFilterAction, series.length, setHiddenSeries]);
  return useMemo(
    () => /* @__PURE__ */ jsxs(
      "g",
      {
        onClick: handleOnClick,
        className: "cell",
        style: hiddenSeries.includes(domainValue) ? { opacity: 0.2, cursor: "pointer" } : { cursor: "pointer" },
        children: [
          /* @__PURE__ */ jsx(LegendIcon, { fill: colorScale(domainValue) }),
          /* @__PURE__ */ jsx("text", { x: 24, dy: ".32em", fontWeight: "600", children: domainValue })
        ]
      },
      domainValue
    ),
    [LegendIcon, colorScale, domainValue, handleOnClick, hiddenSeries]
  );
};
export {
  LegendItem
};
//# sourceMappingURL=LegendItem.js.map
