import * as React from "react";
import { jsx } from "react/jsx-runtime";
import { useContext, useMemo, useEffect, useRef, useState } from "react";
import { select } from "d3";
import { ChartContext } from "../../ChartContext.js";
import { LegendItem } from "./LegendItem.js";
const TopLegend = () => {
  const {
    colorScale,
    currentData,
    internalMargin,
    innerWidth,
    setTopLegend,
    width: graphWidth
  } = useContext(ChartContext);
  const ref = useRef(null);
  const [xTransform, setXTransform] = useState(innerWidth / 2 + internalMargin.left);
  useEffect(() => {
    if (ref.current) {
      const cells = select(ref.current).selectAll(".cell");
      const padding = 30;
      let offset = 0;
      let verticalOffset = 0;
      currentData.forEach((_, i) => {
        if (cells.nodes()[i - 1]) {
          const lastCell = select(cells.nodes()[i - 1]);
          const d3sel = select(cells.nodes()[i]);
          const { width: currentCellWidth } = d3sel.node()?.getBBox() || { width: 0 };
          const lastCellWidth = lastCell.node()?.getBBox()?.width || 0;
          if (offset + lastCellWidth + padding + currentCellWidth + 10 > graphWidth) {
            offset = 0;
            verticalOffset += 20;
          } else {
            offset += lastCellWidth + padding;
          }
          d3sel.attr("transform", `translate(${offset}, ${verticalOffset})`);
        }
      });
      const bounds = ref.current.getBoundingClientRect();
      setXTransform(innerWidth / 2 + internalMargin.left - bounds.width / 2);
    }
  }, [currentData, graphWidth, innerWidth, internalMargin.left]);
  return useMemo(
    () => /* @__PURE__ */ jsx("g", { ref, transform: `translate(${xTransform},10)`, children: /* @__PURE__ */ jsx("g", { ref: setTopLegend, children: colorScale.domain().map((domainValue) => /* @__PURE__ */ jsx(LegendItem, { domainValue }, domainValue)) }) }),
    [xTransform, setTopLegend, colorScale]
  );
};
export {
  TopLegend
};
//# sourceMappingURL=TopLegend.js.map
