import * as React from "react";
import { jsx } from "react/jsx-runtime";
import { useContext, useMemo } from "react";
import { ChartContext } from "../../ChartContext.js";
import { ScrapperLine } from "./ScrapperLine.js";
const Scrapper = () => {
  const {
    yScale,
    getXValue,
    getYValue,
    getYScaleValue,
    getXScaleValue,
    getBandwidth,
    currentData: data
  } = useContext(ChartContext);
  const isBandAxis = yScale?.type === "BAND";
  const uniqueData = useMemo(() => {
    let valueToPositionPerSeries;
    if (isBandAxis) {
      valueToPositionPerSeries = data.map(
        (serie) => serie.data.map((datum) => {
          const x = getXValue(datum);
          const y = getYValue(datum);
          return {
            position: getYScaleValue(datum),
            name: serie.name,
            xValue: x,
            yValue: y,
            key: datum.position,
            datum,
            color: serie.color
          };
        })
      ).flat(1);
    } else {
      valueToPositionPerSeries = data.map(
        (serie) => serie.data.map((datum) => ({
          position: getXScaleValue(datum),
          name: serie.name,
          xValue: getXValue(datum),
          yValue: getYValue(datum),
          key: datum.position,
          datum,
          color: serie.color
        }))
      ).flat(1);
    }
    const positionUniqueData = {};
    valueToPositionPerSeries.forEach((set) => {
      if (!set.position) return;
      if (positionUniqueData[set.position]) {
        positionUniqueData[set.position] = [...positionUniqueData[set.position], { ...set }];
      } else {
        positionUniqueData[set.position] = [{ ...set }];
      }
    });
    return positionUniqueData;
  }, [data, getXScaleValue, getXValue, getYScaleValue, getYValue, isBandAxis]);
  return /* @__PURE__ */ jsx("g", { children: Object.keys(uniqueData).map((key) => {
    const yPosition = parseFloat(key) + (isBandAxis ? getBandwidth() / 2 : 0);
    const datum = uniqueData[key];
    return /* @__PURE__ */ jsx(ScrapperLine, { yPosition, datum }, key);
  }) });
};
export {
  Scrapper
};
//# sourceMappingURL=Scrapper.js.map
