import * as React from "react";
import { jsx } from "react/jsx-runtime";
import { useContext, useCallback, useMemo } from "react";
import { styled } from "@elliemae/ds-system";
import { ChartContext } from "../../ChartContext.js";
import { TOOLBAR } from "../../../constants.js";
const StyledResetter = styled("g")`
  cursor: ${({ isDisabled }) => isDisabled ? "not-allowed" : "pointer"};
  opacity: ${({ isDisabled }) => isDisabled ? "0.4" : "1"};
  &focus {
    outline: 2px solid blue;
  }
`;
const Controllers = () => {
  const {
    props: { xScroll },
    width,
    internalMargin,
    xScale,
    yScale,
    containerRef,
    containerRatio,
    setContainerRatio,
    lastScrollbarPosition,
    setToolbarRef,
    setXScrollbarPosition
  } = useContext(ChartContext);
  const isDisabled = useMemo(() => containerRatio === 1, [containerRatio]);
  const handleOnClick = useCallback(() => {
    setContainerRatio(1);
    setXScrollbarPosition(0);
    lastScrollbarPosition.current = 0;
  }, [lastScrollbarPosition, setContainerRatio, setXScrollbarPosition]);
  const handleOnKeyDown = useCallback(
    (e) => {
      e.stopPropagation();
      if (["Space", "Enter"].includes(e.code)) {
        setContainerRatio(1);
        setXScrollbarPosition(0);
        lastScrollbarPosition.current = 0;
        containerRef?.focus();
      }
      if (e.code === "Tab" && e.shiftKey) {
        e.preventDefault();
        containerRef?.focus();
      }
    },
    [containerRef, lastScrollbarPosition, setContainerRatio, setXScrollbarPosition]
  );
  if (xScale?.type === "BAND" || yScale?.type === "BAND") return null;
  if (!xScroll) return null;
  return /* @__PURE__ */ jsx(
    StyledResetter,
    {
      onClick: handleOnClick,
      onKeyDown: handleOnKeyDown,
      transform: `translate(${width - TOOLBAR.RESET.WIDTH * 2},${internalMargin.top / 2 - TOOLBAR.RESET.HEIGHT / 2})`,
      strokeLinecap: "round",
      isDisabled,
      innerRef: setToolbarRef,
      role: "button",
      "aria-label": "Reset zoom in chart",
      tabIndex: isDisabled ? -1 : 0,
      children: /* @__PURE__ */ jsx(
        "path",
        {
          d: "M 2.875 7.75 A 5.625 5.625 0 1 1 4.5225 11.7275 L 8.2725 10.7275 L 6.5225 14.9775 L 4.5225 11.7275\n        M 0 0 H 17 V 17 H 0 V 0 ",
          fill: "#ffffff",
          stroke: "#000000",
          strokeLinecap: "round",
          strokeWidth: "1"
        }
      )
    }
  );
};
export {
  Controllers
};
//# sourceMappingURL=Controllers.js.map
