import * as React from "react";
import { jsx, jsxs } from "react/jsx-runtime";
import { useContext, useCallback, useMemo } from "react";
import { ChartContext } from "../../ChartContext.js";
const ScrollBarX = () => {
  const {
    setIsGrabbed,
    setStartPosition,
    innerWidth,
    xScrollbarPosition,
    activePoint,
    setXScrollbarPosition,
    innerHeight,
    isGrabbed,
    containerRatio,
    setScrapperPosX,
    isScrollbarVisible,
    lastScrollbarPosition
  } = useContext(ChartContext);
  const barWidth = useMemo(() => innerWidth / containerRatio, [containerRatio, innerWidth]);
  const handleMouseDown = useCallback(
    (e) => {
      e.stopPropagation();
      setScrapperPosX(-1);
      setIsGrabbed(true);
      setStartPosition(e.clientX);
      e.preventDefault();
    },
    [setIsGrabbed, setScrapperPosX, setStartPosition]
  );
  const handleMouseEnter = useCallback(() => {
    setScrapperPosX(-1);
  }, [setScrapperPosX]);
  const handleClickFullBar = useCallback(
    (e) => {
      let newPosition = 0;
      const bar = e.target;
      const bounds = bar.getBoundingClientRect();
      const left = e.clientX - bounds.left;
      if (left + barWidth / 2 > innerWidth) {
        newPosition = innerWidth - barWidth;
      } else if (left - barWidth / 2 > 0) {
        newPosition = left - barWidth / 2;
      }
      setXScrollbarPosition(newPosition);
      lastScrollbarPosition.current = newPosition;
      e.preventDefault();
    },
    [barWidth, innerWidth, lastScrollbarPosition, setXScrollbarPosition]
  );
  const isBarVisible = useMemo(
    () => (isScrollbarVisible || activePoint) && containerRatio > 1,
    [activePoint, containerRatio, isScrollbarVisible]
  );
  return /* @__PURE__ */ jsxs(
    "g",
    {
      className: "scrollbarx",
      transform: `translate(0,${innerHeight})`,
      style: { visibility: isBarVisible ? "visible" : "hidden" },
      onMouseEnter: handleMouseEnter,
      children: [
        /* @__PURE__ */ jsx("rect", { style: { cursor: "pointer" }, width: innerWidth, height: "6", fill: "#ebecf0c5", onClick: handleClickFullBar }),
        /* @__PURE__ */ jsx("g", { transform: `translate(${xScrollbarPosition},0)`, children: /* @__PURE__ */ jsx(
          "rect",
          {
            style: { cursor: isGrabbed ? "grabbing" : "grab" },
            width: barWidth,
            height: "6",
            fill: "grey",
            onMouseDown: handleMouseDown
          }
        ) })
      ]
    }
  );
};
export {
  ScrollBarX
};
//# sourceMappingURL=ScrollBarX.js.map
