import * as React from "react";
import { jsx, jsxs } from "react/jsx-runtime";
import { useContext, useCallback, useMemo } from "react";
import { ChartContext } from "../../ChartContext.js";
const ScrollBarY = () => {
  const {
    setIsGrabbed,
    setStartPosition,
    xScrollbarPosition,
    activePoint,
    setXScrollbarPosition,
    innerHeight,
    isGrabbed,
    containerRatio,
    setScrapperPosX,
    setScrapperPosY,
    isScrollbarVisible,
    lastScrollbarPosition
  } = useContext(ChartContext);
  const barHeight = useMemo(() => Math.round(innerHeight / containerRatio), [containerRatio, innerHeight]);
  const handleMouseDown = useCallback(
    (e) => {
      setScrapperPosX(-1);
      setScrapperPosY(-1);
      setIsGrabbed(true);
      setStartPosition(e.clientY);
      e.preventDefault();
    },
    [setIsGrabbed, setScrapperPosY, setScrapperPosX, setStartPosition]
  );
  const handleMouseEnter = useCallback(() => {
    setScrapperPosX(-1);
  }, [setScrapperPosX]);
  const handleClickFullBar = useCallback(
    (e) => {
      let newPosition = 0;
      const bar = e.target;
      const bounds = bar.getBoundingClientRect();
      const top = e.clientY - bounds.top;
      if (top + barHeight / 2 > innerHeight) {
        newPosition = innerHeight - barHeight;
      } else if (top - barHeight / 2 > 0) {
        newPosition = top - barHeight / 2;
      }
      setXScrollbarPosition(newPosition);
      lastScrollbarPosition.current = newPosition;
      e.preventDefault();
    },
    [barHeight, innerHeight, lastScrollbarPosition, setXScrollbarPosition]
  );
  const isBarVisible = useMemo(
    () => (isScrollbarVisible || activePoint) && containerRatio > 1,
    [activePoint, containerRatio, isScrollbarVisible]
  );
  return /* @__PURE__ */ jsxs(
    "g",
    {
      className: "scrollbary",
      transform: "translate(-6,0)",
      style: { visibility: isBarVisible ? "visible" : "hidden" },
      onMouseEnter: handleMouseEnter,
      children: [
        /* @__PURE__ */ jsx(
          "rect",
          {
            style: { cursor: "pointer" },
            width: "6",
            height: innerHeight,
            fill: "#ebecf0c5",
            onClick: handleClickFullBar
          }
        ),
        /* @__PURE__ */ jsx("g", { transform: `translate(0,${xScrollbarPosition})`, children: /* @__PURE__ */ jsx(
          "rect",
          {
            style: { cursor: isGrabbed ? "grabbing" : "grab" },
            width: "6",
            height: barHeight,
            fill: "grey",
            onMouseDown: handleMouseDown
          }
        ) })
      ]
    }
  );
};
export {
  ScrollBarY
};
//# sourceMappingURL=ScrollBarY.js.map
