import * as React from "react";
import { jsx, jsxs } from "react/jsx-runtime";
import { useContext, useCallback, useMemo } from "react";
import { ChartContext } from "../../ChartContext.js";
import { AxisBottom } from "../Axis/AxisBottom.js";
import { SeriesFactory } from "../SeriesFactory.js";
import { ScrollBarX } from "./ScrollBarX.js";
import { Scrapper } from "../Scrapper/Scrapper.js";
import { VerticalScrapper } from "../Scrapper/VerticalScrapper.js";
const ScrollableContainerX = () => {
  const {
    props: { scrapper },
    xScrollbarPosition,
    xScale,
    containerRatio,
    innerWidth,
    isGrabbed,
    containerRef,
    setXScrollbarPosition,
    setContainerRatio,
    lastScrollbarPosition,
    innerHeight,
    internalMargin,
    chartId,
    isZooming,
    setIsZooming,
    zoomStartingPosition,
    setZoomStartingPosition,
    movingPosition,
    setMovingPosition
  } = useContext(ChartContext);
  const getRealClientX = useCallback(
    (clientX) => clientX - internalMargin.left - (containerRef?.getBoundingClientRect().left || 0),
    [containerRef, internalMargin.left]
  );
  const Scrappers = useMemo(() => {
    if (scrapper && scrapper?.type === "horizontal") return /* @__PURE__ */ jsx(Scrapper, {});
    if (scrapper && scrapper?.type === "vertical") return /* @__PURE__ */ jsx(VerticalScrapper, {});
    return null;
  }, [scrapper]);
  const handleOnMouseDown = useCallback(
    ({ clientX }) => {
      if (!isGrabbed && xScale?.type !== "BAND") {
        setIsZooming(true);
        setZoomStartingPosition(getRealClientX(clientX));
        setMovingPosition(0);
      }
    },
    [getRealClientX, isGrabbed, setIsZooming, setMovingPosition, setZoomStartingPosition, xScale?.type]
  );
  const handleOnMouseMove = useCallback(
    ({ clientX }) => {
      if (isZooming) setMovingPosition(getRealClientX(clientX));
    },
    [getRealClientX, isZooming, setMovingPosition]
  );
  const handleOnMouseUp = useCallback(
    (e) => {
      if (!isZooming) return;
      setIsZooming(false);
      setMovingPosition(0);
      const endingPosition = getRealClientX(e.clientX);
      const diff = Math.abs(zoomStartingPosition - endingPosition);
      if (diff <= 0) return;
      const newRatio = innerWidth / (innerWidth * containerRatio / diff) < 40 ? innerWidth / 40 : innerWidth * containerRatio / diff;
      const newPosition = lastScrollbarPosition.current + (zoomStartingPosition > endingPosition ? endingPosition : zoomStartingPosition) / containerRatio;
      if (newPosition > innerWidth - innerWidth / newRatio) setXScrollbarPosition(innerWidth - innerWidth / newRatio);
      else setXScrollbarPosition(newPosition);
      setContainerRatio(newRatio);
      lastScrollbarPosition.current = newPosition;
      e.stopPropagation();
    },
    [
      isZooming,
      setIsZooming,
      setMovingPosition,
      getRealClientX,
      zoomStartingPosition,
      innerWidth,
      containerRatio,
      lastScrollbarPosition,
      setXScrollbarPosition,
      setContainerRatio
    ]
  );
  return /* @__PURE__ */ jsxs(
    "g",
    {
      className: "scrollable-container-x",
      onMouseDown: handleOnMouseDown,
      onMouseMove: handleOnMouseMove,
      onMouseUp: handleOnMouseUp,
      children: [
        /* @__PURE__ */ jsxs("g", { mask: `url(#mask-${chartId})`, children: [
          /* @__PURE__ */ jsxs("g", { transform: `translate(${-xScrollbarPosition * containerRatio},0)`, children: [
            /* @__PURE__ */ jsx(AxisBottom, {}),
            /* @__PURE__ */ jsx(SeriesFactory, {}),
            Scrappers
          ] }),
          isZooming && movingPosition !== 0 ? /* @__PURE__ */ jsx(
            "rect",
            {
              x: movingPosition < zoomStartingPosition ? movingPosition : zoomStartingPosition,
              width: Math.abs(movingPosition - zoomStartingPosition),
              height: innerHeight,
              fill: "orange",
              style: { opacity: 0.2 }
            }
          ) : null
        ] }),
        /* @__PURE__ */ jsx(ScrollBarX, {})
      ]
    }
  );
};
export {
  ScrollableContainerX
};
//# sourceMappingURL=ScrollableContainerX.js.map
