import * as React from "react";
import { jsx } from "react/jsx-runtime";
import { useContext, useMemo } from "react";
import { ChartContext } from "../ChartContext.js";
import { Line, Points, Bars, StackedBar, Area, HorizontalBars, HorizontalStackedBars } from "../series/index.js";
import { getStackedIndex } from "../helpers/index.js";
import { useVirtualizedSeries } from "../helpers/useVirtualizedSeries.js";
const SeriesFactory = () => {
  const {
    props: { groups, types },
    isHorizontal
  } = useContext(ChartContext);
  const virtualizedSeries = useVirtualizedSeries();
  return useMemo(
    () => /* @__PURE__ */ jsx("g", { className: "content", children: virtualizedSeries.map((serie) => {
      const serieProps = {
        key: serie.key,
        serie
      };
      if (serie.type === "bar" && groups && getStackedIndex(groups, serie.name) > -1 && isHorizontal) {
        return /* @__PURE__ */ jsx(HorizontalStackedBars, { ...serieProps });
      }
      if (serie.type === "bar" && groups && getStackedIndex(groups, serie.name) > -1) {
        return /* @__PURE__ */ jsx(StackedBar, { ...serieProps });
      }
      if (serie.type === "bar" && isHorizontal) {
        return /* @__PURE__ */ jsx(HorizontalBars, { ...serieProps });
      }
      if (serie.type === "bar") {
        return /* @__PURE__ */ jsx(Bars, { ...serieProps });
      }
      if (types === "scatter" && !serie.type || serie.type === "point") {
        return /* @__PURE__ */ jsx(Points, { ...serieProps });
      }
      if (serie.type === "line") {
        return /* @__PURE__ */ jsx(Line, { ...serieProps });
      }
      if (serie.type === "area") {
        return /* @__PURE__ */ jsx(Area, { ...serieProps });
      }
      return null;
    }) }),
    [groups, isHorizontal, types, virtualizedSeries]
  );
};
export {
  SeriesFactory
};
//# sourceMappingURL=SeriesFactory.js.map
