import * as React from "react";
import { jsx, jsxs } from "react/jsx-runtime";
import { useContext, useMemo } from "react";
import { area, line } from "d3";
import { StyledArea } from "../styles.js";
import { ChartContext } from "../ChartContext.js";
import { getStackedData } from "../helpers/index.js";
import { Points } from "./Points.js";
import { LINE, curveStyleMap } from "../../constants.js";
const Area = ({ serie }) => {
  const { xScale, getXScaleValue, getY2ScaleValue, getYScaleValue, innerHeight, colorScale, stackedData } = useContext(ChartContext);
  const finalYScale = serie.scale === "y2" ? getY2ScaleValue : getYScaleValue;
  const curveStyle = useMemo(() => curveStyleMap[serie.curveStyle ?? LINE.CURVE_STYLE.LINEAR], [serie.curveStyle]);
  const areaD3 = useMemo(() => {
    const serieWithStackedValues = getStackedData(stackedData, serie);
    if (serieWithStackedValues) {
      return area().x((_, i) => getXScaleValue(serie.data[i])).y0(([, y2]) => finalYScale(y2)).y1(([y1]) => finalYScale(y1)).curve(curveStyle)(serieWithStackedValues);
    }
    return area().x((_, i) => getXScaleValue(serie.data[i])).y0(innerHeight).y1((_, i) => getYScaleValue(serie.data[i])).curve(curveStyle)(serie.data);
  }, [stackedData, serie, innerHeight, curveStyle, getXScaleValue, finalYScale, getYScaleValue]);
  const lineD3 = useMemo(() => {
    const serieWithStackedValues = getStackedData(stackedData, serie);
    if (serieWithStackedValues) {
      return line().x((_, i) => getXScaleValue(serie.data[i])).y(([, y2]) => finalYScale(y2)).curve(curveStyle)(serieWithStackedValues);
    }
    return line().x((_, i) => getXScaleValue(serie.data[i])).y((_, i) => getYScaleValue(serie.data[i])).curve(curveStyle)(serie.data);
  }, [stackedData, serie, curveStyle, getXScaleValue, finalYScale, getYScaleValue]);
  const xTranslate = (xScale?.getBandwidth() ?? 0) / 2;
  return /* @__PURE__ */ jsx("g", { children: /* @__PURE__ */ jsxs("g", { transform: `translate(${xTranslate}, 0)`, children: [
    /* @__PURE__ */ jsx(Points, { serie }),
    /* @__PURE__ */ jsx("path", { d: lineD3 ?? "", fill: "none", strokeWidth: 2, stroke: colorScale(serie.name) }),
    /* @__PURE__ */ jsx(StyledArea, { d: areaD3 ?? "", fill: colorScale(serie.name) })
  ] }) });
};
export {
  Area
};
//# sourceMappingURL=Area.js.map
