import * as React from "react";
import { jsx } from "react/jsx-runtime";
import { useContext } from "react";
import { Rect } from "./Rect.js";
import { ChartContext } from "../ChartContext.js";
import { A11yRegion } from "../parts/A11yRegion.js";
const Bars = ({ serie }) => {
  const {
    innerHeight,
    xScale,
    getXScaleValue,
    getYScaleValue,
    getY2ScaleValue,
    subGroupScale,
    colorScale,
    getXValue,
    getYValue,
    chartId
  } = useContext(ChartContext);
  const finalYScale = serie.scale === "y2" ? getY2ScaleValue : getYScaleValue;
  const negativeSize = innerHeight - finalYScale(0);
  const positiveSize = innerHeight - negativeSize;
  return /* @__PURE__ */ jsx(
    A11yRegion,
    {
      serieName: serie.name,
      clipPath: `url(#rect-focus-ring-${chartId})`,
      fill: colorScale(serie.name),
      children: serie.data.map((bar) => {
        const x = getXValue(bar);
        const y = getYValue(bar);
        const xScaled = getXScaleValue(bar) ?? 0;
        const yScaled = finalYScale(bar) ?? 0;
        const width = subGroupScale?.bandwidth() ?? 0;
        const height = y > 0 ? positiveSize - yScaled : yScaled - finalYScale(0);
        const transformX = xScale?.type !== "BAND" ? xScaled - width / 2 : ((subGroupScale && subGroupScale(serie.name)) ?? 0) + xScaled;
        const transformY = y > 0 ? finalYScale(0) - height : finalYScale(0);
        return /* @__PURE__ */ jsx("g", { id: `${chartId}-${serie.name}-rects-${bar.key}`, transform: `translate(${transformX},0)`, children: /* @__PURE__ */ jsx(
          Rect,
          {
            name: serie.name,
            xValue: x,
            yValue: y,
            width,
            height,
            id: bar.key,
            y: transformY,
            isNegative: y < 0,
            datum: bar
          }
        ) }, bar.key);
      })
    }
  );
};
export {
  Bars
};
//# sourceMappingURL=Bars.js.map
