import * as React from "react";
import { jsx } from "react/jsx-runtime";
import { useContext, useMemo } from "react";
import { Rect } from "./Rect.js";
import { ChartContext } from "../ChartContext.js";
const HorizontalBars = ({ serie }) => {
  const {
    innerWidth,
    subGroupScale,
    getYScaleValue,
    getY2ScaleValue,
    getXScaleValue,
    colorScale,
    getXValue,
    getYValue,
    chartId
  } = useContext(ChartContext);
  const finalYScale = serie.scale === "y2" ? getY2ScaleValue : getYScaleValue;
  const negativeSize = innerWidth - getXScaleValue(0);
  const positiveSize = innerWidth - negativeSize;
  return useMemo(
    () => /* @__PURE__ */ jsx("g", { fill: colorScale(serie.name), clipPath: `url(#rect-focus-ring-${chartId})`, children: serie.data.map((bar) => {
      const x = getXValue(bar);
      const y = getYValue(bar);
      const xScaled = getXScaleValue(bar) ?? 0;
      const width = x < 0 ? positiveSize - xScaled : xScaled - getXScaleValue(0);
      const height = subGroupScale?.bandwidth() ?? 0;
      const transformX = x < 0 ? getXScaleValue(0) - width : getXScaleValue(0);
      const transformY = ((subGroupScale && subGroupScale(serie.name)) ?? 0) + finalYScale(y);
      return /* @__PURE__ */ jsx("g", { transform: `translate(${transformX},${transformY})`, children: /* @__PURE__ */ jsx(
        Rect,
        {
          datum: bar,
          name: serie.name,
          width,
          height,
          id: bar.key,
          x: 0,
          xValue: x,
          yValue: y
        }
      ) }, bar.key);
    }) }),
    [
      chartId,
      colorScale,
      finalYScale,
      getXScaleValue,
      getXValue,
      getYValue,
      positiveSize,
      serie.data,
      serie.name,
      subGroupScale
    ]
  );
};
export {
  HorizontalBars
};
//# sourceMappingURL=HorizontalBars.js.map
