import * as React from "react";
import { jsx } from "react/jsx-runtime";
import { useContext, useMemo } from "react";
import { Rect } from "./Rect.js";
import { ChartContext } from "../ChartContext.js";
import { getStackedData, getStackedIndex } from "../helpers/index.js";
const HorizontalStackedBars = ({ serie }) => {
  const {
    props: { groups },
    yScale,
    stackedData,
    subGroupScale,
    colorScale,
    chartId,
    getXScaleValue,
    getYValue
  } = useContext(ChartContext);
  const serieWithStackedValues = getStackedData(stackedData, serie);
  const stackIndex = getStackedIndex(groups, serie.name);
  return useMemo(
    () => /* @__PURE__ */ jsx("g", { children: serie.data.map((bar, i) => {
      const sequence = serieWithStackedValues ? serieWithStackedValues[bar.position] : [0, 0];
      const sequence0 = getXScaleValue(sequence[0]);
      const sequence1 = getXScaleValue(sequence[1]);
      const isFloorStack = sequence[0] === 0;
      const xValue = sequence[1] - sequence[0];
      const yValue = getYValue(serie.data[i]);
      const width = sequence1 - sequence0 - (!isFloorStack ? 2 : 0);
      const height = subGroupScale?.bandwidth() ?? 0;
      const transformX = sequence0 + (!isFloorStack ? 2 : 0);
      const transformY = (subGroupScale ? subGroupScale(`stacked-data-${stackIndex}`) ?? 0 : 0) + (yScale?.get(yValue) ?? 0);
      return /* @__PURE__ */ jsx("g", { clipPath: `url(#rect-focus-ring-${chartId})`, children: /* @__PURE__ */ jsx("g", { fill: colorScale(serie.name), transform: `translate(0, ${transformY})`, children: /* @__PURE__ */ jsx(
        Rect,
        {
          width,
          height,
          x: transformX,
          xValue,
          yValue,
          id: serie.data[i]?.key,
          name: serie.name,
          datum: serie.data[i]
        }
      ) }) }, serie.data[i]?.key);
    }) }),
    [
      chartId,
      colorScale,
      getXScaleValue,
      getYValue,
      serie.data,
      serie.name,
      serieWithStackedValues,
      stackIndex,
      subGroupScale,
      yScale
    ]
  );
};
export {
  HorizontalStackedBars
};
//# sourceMappingURL=HorizontalStackedBars.js.map
