import * as React from "react";
import { jsx, jsxs } from "react/jsx-runtime";
import { useContext, useEffect, useMemo, useRef } from "react";
import { line, select } from "d3";
import { Points } from "./Points.js";
import { ChartContext } from "../ChartContext.js";
import { LINE, curveStyleMap } from "../../constants.js";
import { DataVizDataTestIds } from "../DataTestIds.js";
import { A11yRegion } from "../parts/A11yRegion.js";
const Line = ({ serie }) => {
  const { xScale, colorScale, getYScaleValue, getY2ScaleValue, getXScaleValue, getXValue, getYValue } = useContext(ChartContext);
  const ref = useRef(null);
  const curveStyle = useMemo(() => curveStyleMap[serie.curveStyle ?? LINE.CURVE_STYLE.LINEAR], [serie.curveStyle]);
  const currentYScale = useMemo(
    () => serie.scale === "y2" ? getY2ScaleValue : getYScaleValue,
    [getY2ScaleValue, getYScaleValue, serie.scale]
  );
  const lineD3 = useMemo(
    () => line().x((_, i) => getXScaleValue(serie.data[i])).y((_, i) => currentYScale(serie.data[i])).curve(curveStyle),
    [curveStyle, getXScaleValue, currentYScale, serie.data]
  );
  useEffect(() => {
    if (!ref.current) return;
    const groupContent = select(ref?.current);
    groupContent.selectAll("*").remove();
    const path = groupContent.append("path").datum(serie.data).attr("fill", "none").attr("stroke", colorScale(serie.name)).attr("stroke-linejoin", "round").attr("stroke-width", 2).attr("d", lineD3);
    if (serie.dashStyle)
      path.attr("stroke-dasharray", LINE.DASH_STYLE_VALUES[serie.dashStyle]);
  }, [colorScale, getXValue, getYValue, lineD3, serie, xScale]);
  const xTranslate = useMemo(() => (xScale?.getBandwidth?.() ?? 0) / 2, [xScale]);
  return /* @__PURE__ */ jsxs(A11yRegion, { serieName: serie.name, transform: `translate(${xTranslate}, 0)`, children: [
    /* @__PURE__ */ jsx("g", { ref, "data-testid": DataVizDataTestIds.LINE }),
    /* @__PURE__ */ jsx(Points, { serie })
  ] });
};
export {
  Line
};
//# sourceMappingURL=Line.js.map
