import * as React from "react";
import { Fragment, jsx, jsxs } from "react/jsx-runtime";
import { useContext, useCallback, useMemo } from "react";
import { ChartContext } from "../ChartContext.js";
import { FOCUS_RING, SCRAPPER, LINE } from "../../constants.js";
import { FocusableRegion } from "../parts/FocusableRegion.js";
import { TrendHighlight } from "../parts/TrendHighlight.js";
import { DataVizDataTestIds } from "../DataTestIds.js";
const Point = ({
  x,
  y,
  xValue,
  yValue,
  name,
  pointStyle,
  pointRadius,
  id,
  opacity,
  datum
}) => {
  const {
    activePoint,
    scrapperPosY,
    scrapperPosX,
    getYValueFormatted,
    getXValueFormatted,
    setActivePoint,
    props: { scrapper, TooltipRenderer, withTrendHighlight, y2Axis, yAxis, xAxis }
  } = useContext(ChartContext);
  const finalYAxis = datum.scale === "y2" ? y2Axis : yAxis;
  const yValueFormatted = getYValueFormatted(datum);
  const xValueFormatted = getXValueFormatted(datum);
  const isFocused = useMemo(() => {
    if (activePoint?.key === id) {
      return true;
    }
    if (scrapper?.type === SCRAPPER.TYPE_HORIZONTAL) {
      return y === scrapperPosY;
    }
    if (scrapper?.type === SCRAPPER.TYPE_VERTICAL) {
      return x === scrapperPosX;
    }
    return false;
  }, [activePoint, id, scrapper, y, scrapperPosY, x, scrapperPosX]);
  const point = useMemo(() => {
    const commonProps = {
      tabIndex: -1,
      ref: (_ref) => {
        if (isFocused) {
          _ref?.focus();
        }
      },
      "aria-label": `${datum.serie} ${xAxis.label || ""} ${xValueFormatted} ${finalYAxis?.label || ""} ${yValueFormatted}`,
      role: "img"
    };
    if (LINE.POINT_STYLE.DIAMOND === pointStyle) {
      const squareEdge = pointRadius * 2;
      return /* @__PURE__ */ jsxs("g", { transform: "rotate(45)", children: [
        isFocused ? /* @__PURE__ */ jsx(
          "rect",
          {
            x: -pointRadius - FOCUS_RING.STROKE_WIDTH,
            y: -pointRadius - FOCUS_RING.STROKE_WIDTH,
            width: squareEdge + FOCUS_RING.STROKE_WIDTH * 2,
            height: squareEdge + FOCUS_RING.STROKE_WIDTH * 2,
            fill: "none",
            stroke: FOCUS_RING.COLOR,
            strokeWidth: FOCUS_RING.STROKE_WIDTH
          }
        ) : null,
        /* @__PURE__ */ jsx("rect", { ...commonProps, x: -pointRadius, y: -pointRadius, width: squareEdge, height: squareEdge })
      ] });
    }
    if (LINE.POINT_STYLE.SQUARE === pointStyle) {
      const squareEdge = pointRadius * 2;
      return /* @__PURE__ */ jsxs("g", { children: [
        isFocused ? /* @__PURE__ */ jsx(
          "rect",
          {
            x: -pointRadius - FOCUS_RING.STROKE_WIDTH,
            y: -pointRadius - FOCUS_RING.STROKE_WIDTH,
            width: squareEdge + FOCUS_RING.STROKE_WIDTH * 2,
            height: squareEdge + FOCUS_RING.STROKE_WIDTH * 2,
            fill: "none",
            stroke: FOCUS_RING.COLOR,
            strokeWidth: FOCUS_RING.STROKE_WIDTH
          }
        ) : null,
        /* @__PURE__ */ jsx("rect", { ...commonProps, x: -pointRadius, y: -pointRadius, width: squareEdge, height: squareEdge })
      ] });
    }
    return /* @__PURE__ */ jsxs("g", { children: [
      isFocused ? /* @__PURE__ */ jsx("g", { children: /* @__PURE__ */ jsx(
        "circle",
        {
          r: (pointRadius ?? LINE.DEFAULT_POINT_RADIUS) + FOCUS_RING.STROKE_WIDTH,
          fill: "none",
          stroke: FOCUS_RING.COLOR,
          strokeWidth: FOCUS_RING.STROKE_WIDTH
        }
      ) }) : null,
      /* @__PURE__ */ jsx(
        "circle",
        {
          ...commonProps,
          r: pointRadius ?? (isFocused ? LINE.DEFAULT_POINT_RADIUS : 0),
          opacity
        }
      )
    ] });
  }, [
    datum.serie,
    finalYAxis?.label,
    isFocused,
    opacity,
    pointRadius,
    pointStyle,
    xAxis.label,
    xValueFormatted,
    yValueFormatted
  ]);
  const handleMouseEnter = useCallback(() => {
    if (!scrapper) setActivePoint(datum);
  }, [datum, scrapper, setActivePoint]);
  const handleOnMouseLeave = useCallback(() => {
    if (!scrapper) setActivePoint(null);
  }, [scrapper, setActivePoint]);
  return /* @__PURE__ */ jsxs(Fragment, { children: [
    /* @__PURE__ */ jsxs(
      "g",
      {
        "data-testid": DataVizDataTestIds.POINT,
        onMouseEnter: handleMouseEnter,
        onMouseLeave: handleOnMouseLeave,
        transform: `translate(${x},${y})`,
        children: [
          point,
          activePoint?.key === id && TooltipRenderer ? /* @__PURE__ */ jsx(
            FocusableRegion,
            {
              id,
              width: (pointRadius ?? 3) * 4,
              height: (pointRadius ?? 3) * 4,
              style: { transform: `translate(-${pointRadius ?? 3}px, -${pointRadius ?? 3}px)` },
              content: /* @__PURE__ */ jsx(TooltipRenderer, { data: [{ name, yValue, xValue, datum }] })
            }
          ) : null
        ]
      }
    ),
    isFocused && withTrendHighlight ? /* @__PURE__ */ jsx(TrendHighlight, { currentDatum: datum }) : null
  ] });
};
export {
  Point
};
//# sourceMappingURL=Point.js.map
