import * as React from "react";
import { jsx } from "react/jsx-runtime";
import { useMemo, useContext } from "react";
import { Point } from "./Point.js";
import { ChartContext } from "../ChartContext.js";
import { getStackedData } from "../helpers/index.js";
const Points = ({ serie }) => {
  const {
    colorScale,
    getXValue,
    getYValue,
    getY2ScaleValue,
    getYScaleValue,
    getXScaleValue,
    stackedData,
    props: { types }
  } = useContext(ChartContext);
  const finalYScale = serie.scale === "y2" ? getY2ScaleValue : getYScaleValue;
  const opacity = useMemo(() => types === "scatter" ? 0.8 : 1, [types]);
  return useMemo(
    () => /* @__PURE__ */ jsx("g", { fill: colorScale(serie.name), children: serie.data.map((point, i) => {
      const { pointRadius = 0, pointStyle = "" } = serie;
      const serieWithStackedValues = getStackedData(stackedData, serie);
      const deltaY = serieWithStackedValues ? serieWithStackedValues[i][0] : 0;
      const x = getXValue(point);
      const y = getYValue(point);
      const xPosition = getXScaleValue(point) ?? 0;
      const yPosition = finalYScale(y + deltaY);
      return /* @__PURE__ */ jsx(
        Point,
        {
          pointRadius,
          id: point.key,
          opacity,
          x: xPosition,
          y: yPosition,
          xValue: x,
          yValue: y,
          pointStyle,
          name: serie.name,
          datum: point,
          color: colorScale(serie.name)
        },
        `${point.key}-p`
      );
    }) }),
    [colorScale, finalYScale, getXScaleValue, getXValue, getYValue, opacity, serie, stackedData]
  );
};
export {
  Points
};
//# sourceMappingURL=Points.js.map
