import * as React from "react";
import { jsx, jsxs } from "react/jsx-runtime";
import { useMemo, useContext, useCallback } from "react";
import { ChartContext } from "../ChartContext.js";
import { FOCUS_RING } from "../../constants.js";
import { FocusableRegion } from "../parts/FocusableRegion.js";
import { DataVizDataTestIds } from "../DataTestIds.js";
const Rect = ({
  name,
  width,
  height,
  isNegative = false,
  x = 0,
  y = 0,
  id,
  xValue,
  yValue,
  datum
}) => {
  const {
    activePoint,
    chartId,
    isHorizontal,
    setActivePoint,
    getYValueFormatted,
    getXValueFormatted,
    props: { TooltipRenderer, scrapper, xAxis, yAxis, y2Axis }
  } = useContext(ChartContext);
  const finalYAxis = datum.scale === "y2" ? y2Axis : yAxis;
  const yValueFormatted = getYValueFormatted(datum);
  const xValueFormatted = getXValueFormatted(datum);
  const isFocused = activePoint?.key === id;
  const clipPathSign = useMemo(() => {
    if (isHorizontal) return "";
    if (isNegative) return `url(#rects-negative-${chartId})`;
    return `url(#rects-positive-${chartId})`;
  }, [chartId, isHorizontal, isNegative]);
  const transform = useMemo(() => {
    if (isHorizontal) return ``;
    return `scale(1,-1) translate(0,${-height})`;
  }, [height, isHorizontal]);
  const handleMouseEnter = useCallback(() => {
    if (!scrapper) setActivePoint(datum);
  }, [datum, scrapper, setActivePoint]);
  const handleOnMouseLeave = useCallback(() => {
    if (!scrapper) setActivePoint(null);
  }, [scrapper, setActivePoint]);
  return useMemo(
    () => /* @__PURE__ */ jsx("g", { clipPath: clipPathSign, children: /* @__PURE__ */ jsxs(
      "g",
      {
        id: isFocused ? `data-focused-${chartId}` : "",
        transform,
        onMouseEnter: handleMouseEnter,
        onMouseLeave: handleOnMouseLeave,
        "data-testid": DataVizDataTestIds.BAR,
        children: [
          isFocused ? /* @__PURE__ */ jsx(
            "rect",
            {
              x: (isHorizontal ? x : 0) - FOCUS_RING.STROKE_WIDTH,
              y: (!isHorizontal ? -y : 0) - FOCUS_RING.STROKE_WIDTH,
              width: width + FOCUS_RING.OFFSET,
              height: height + FOCUS_RING.OFFSET,
              fill: "none",
              rx: "1",
              ry: "1",
              stroke: FOCUS_RING.COLOR,
              strokeWidth: FOCUS_RING.STROKE_WIDTH
            }
          ) : null,
          /* @__PURE__ */ jsx(
            "rect",
            {
              width,
              height,
              y: -y,
              x,
              "aria-label": `${datum.serie} ${xAxis.label || ""} ${xValueFormatted} ${finalYAxis?.label || ""} ${yValueFormatted}`,
              role: "img",
              tabIndex: -1,
              ref: (_ref) => {
                if (isFocused) {
                  _ref?.focus();
                }
              }
            }
          ),
          activePoint?.key === id && TooltipRenderer ? /* @__PURE__ */ jsx(
            FocusableRegion,
            {
              id,
              y,
              x,
              width,
              height,
              transform,
              content: /* @__PURE__ */ jsx(TooltipRenderer, { data: [{ name, yValue, xValue, datum }] })
            }
          ) : ""
        ]
      }
    ) }),
    [
      clipPathSign,
      isFocused,
      chartId,
      transform,
      handleMouseEnter,
      handleOnMouseLeave,
      isHorizontal,
      x,
      y,
      width,
      height,
      datum,
      xAxis.label,
      xValueFormatted,
      finalYAxis?.label,
      yValueFormatted,
      activePoint?.key,
      id,
      TooltipRenderer,
      name,
      yValue,
      xValue
    ]
  );
};
export {
  Rect
};
//# sourceMappingURL=Rect.js.map
