import * as React from "react";
import { jsx } from "react/jsx-runtime";
import { useContext } from "react";
import { Rect } from "./Rect.js";
import { ChartContext } from "../ChartContext.js";
import { getStackedData, getStackedIndex } from "../helpers/index.js";
const StackedBar = ({ serie }) => {
  const {
    props: { groups },
    xScale,
    yScale,
    stackedData,
    subGroupScale,
    colorScale,
    chartId,
    getXValue,
    getXScaleValue
  } = useContext(ChartContext);
  const serieWithStackedValues = getStackedData(stackedData, serie);
  const stackIndex = getStackedIndex(groups, serie.name);
  return /* @__PURE__ */ jsx("g", { clipPath: `url(#rect-focus-ring-${chartId})`, children: serie.data.map((bar, i) => {
    const sequence = serieWithStackedValues ? serieWithStackedValues[bar.position] : [0, 0];
    const isFloorStack = sequence[0] === 0;
    const xValue = getXValue(bar);
    const xScaleValue = getXScaleValue(bar) ?? 0;
    const yValue = sequence[1] - sequence[0];
    const width = subGroupScale?.bandwidth() ?? 0;
    const height = (yScale?.get(sequence[0]) ?? 0) - (yScale?.get(sequence[1]) ?? 0) - (!isFloorStack ? 1 : 0);
    const transformY = (yScale?.get(sequence[1]) ?? 0) + (sequence[0] < 0 ? 2 : 0);
    const transformX = xScale?.type !== "BAND" ? xScaleValue - width / 2 : xScaleValue + (subGroupScale ? subGroupScale(`stacked-data-${stackIndex}`) ?? 0 : 0);
    return /* @__PURE__ */ jsx("g", { fill: colorScale(serie.name), transform: `translate(${transformX},0)`, children: /* @__PURE__ */ jsx(
      Rect,
      {
        width,
        height,
        xValue,
        yValue,
        y: transformY,
        id: serie.data[i].key,
        name: serie.name,
        datum: bar
      }
    ) }, serie.data[i].key);
  }) });
};
export {
  StackedBar
};
//# sourceMappingURL=StackedBar.js.map
