/// <reference types="react" />
import type { Series, ScaleLinear, ScaleBand } from 'd3';
import { type DSPopperJST } from '@elliemae/ds-popperjs';
import { type SERIE_TYPES } from '../constants.js';
export declare namespace DSChartT {
    type AxisTypeT = 'log' | 'band' | 'time' | 'linear';
    type LinearScale = ScaleLinear<number, number, never>;
    type BandScale = ScaleBand<string>;
    type SeriesTypes = (typeof SERIE_TYPES)[keyof typeof SERIE_TYPES];
    type Scales = LinearScale | BandScale;
    interface SeriesT {
        name: string;
        data: Array<number | null | {
            x: number | string | Date;
            y: number;
        }>;
        type: SeriesTypes;
        scale?: string;
        color: string;
        dashStyle?: string;
        pointRadius?: number;
        pointStyle?: string;
    }
    interface ScrapperT {
        type: 'horizontal' | 'vertical';
        color: string;
        tooltipPreference: DSPopperJST.PopperPlacementsT;
    }
    interface SerieComponentT {
        serie: InternalSerie;
    }
    interface LegendT {
        position: 'right' | 'bottom' | 'left' | 'top';
        preventFilterAction?: boolean;
    }
    interface AxisTickT {
        tickValues?: number[] | Date[];
        tickFormat?: ((value: string | number | Date) => string) | string;
        tickCount?: number;
        tickRotation?: number;
        overwriteTicks?: boolean;
        color?: string;
    }
    type IntervalT = 'DAY' | 'WEEK' | 'MONTH' | 'YEAR';
    interface AxisT {
        type: AxisTypeT;
        showGrid?: boolean;
        color?: string;
        label?: string;
        cols?: string[];
        domainPadding?: number | number[];
        intervalType?: IntervalT;
        hideAxis?: boolean;
        beginAtZero?: boolean;
        advanced?: {
            pointSpacing: {
                type: string;
                value: number;
            };
        };
        tick?: AxisTickT;
        plotRange?: number[];
        min?: number | Date;
        max?: number | Date;
        domainPaddingType?: string;
    }
    interface InternalDatum {
        key: string;
        value: number | {
            x: number;
            y: number;
        };
        position: number;
        serie: string;
        scale: string;
        color: string;
    }
    interface InternalSerie {
        key: string;
        data: InternalDatum[];
        name: string;
        type: SeriesTypes;
        scale?: string | undefined;
        color: string;
        dashStyle?: string;
        pointRadius?: number;
        pointStyle?: string;
        curveStyle?: string;
    }
    type InternalData = InternalSerie[];
    interface TooltipRenderDataT {
        data: {
            datum: InternalDatum;
            name: string;
            xValue: string | number | Date | null;
            yValue: string | number | Date | null;
        }[];
    }
    interface OptionalProps {
        groups?: string[][];
        types?: 'scatter';
        scrapper?: ScrapperT;
        withTrendHighlight?: boolean;
        TooltipRenderer?: React.ComponentType<TooltipRenderDataT>;
        height?: number;
        width?: number;
        legend?: LegendT;
        xScroll?: boolean;
        yScroll?: boolean;
        y2Axis?: AxisT;
        yAxis: AxisT;
        xAxis: AxisT;
    }
    interface DefaultProps {
        series: SeriesT[];
    }
    interface RequiredProps {
    }
    interface Props extends OptionalProps, DefaultProps, RequiredProps {
    }
    type StackedSeriesByGroupT = Series<{
        [key: string]: number;
    }, string>[][];
    interface ScrapperDatum {
        position: number | undefined;
        name: string;
        xValue: string | number | Date | null;
        yValue: string | number | Date | null;
        key: number;
        datum: DSChartT.InternalDatum;
    }
}
export declare const defaultProps: DSChartT.DefaultProps;
export declare const propTypes: {
    height: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    width: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    margin: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    series: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-*': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'on-*': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'data-*': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'all HTML attributes': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    innerRef: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    about: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    accept: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    acceptCharset: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    accessKey: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    action: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    allowFullScreen: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    allowTransparency: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    alt: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-activedescendant': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-atomic': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-autocomplete': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-busy': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-checked': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-colcount': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-colindex': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-colspan': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-controls': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-current': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-describedby': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-details': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-disabled': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-dropeffect': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-errormessage': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-expanded': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-flowto': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-grabbed': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-haspopup': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-hidden': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-invalid': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-keyshortcuts': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-label': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-labelledby': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-level': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-live': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-modal': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-multiline': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-multiselectable': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-orientation': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-owns': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-placeholder': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-posinset': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-pressed': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-readonly': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-relevant': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-required': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-roledescription': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-rowcount': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-rowindex': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-rowspan': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-selected': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-setsize': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-sort': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-valuemax': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-valuemin': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-valuenow': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-valuetext': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    as: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    async: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    autoCapitalize: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    autoComplete: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    autoCorrect: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    autoFocus: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    autoPlay: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    autoSave: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    capture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    cellPadding: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    cellSpacing: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    challenge: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    charSet: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    checked: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    children: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    cite: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    classID: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    className: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    color: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    cols: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    colSpan: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    content: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    contentEditable: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    contextMenu: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    controls: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    coords: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    crossOrigin: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    data: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    datatype: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    dateTime: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    default: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    defaultChecked: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    defaultValue: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    defer: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    dir: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    disabled: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    download: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    draggable: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    encType: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    enterKeyHint: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    form: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    formAction: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    formEncType: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    formMethod: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    formNoValidate: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    formTarget: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    frameBorder: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    headers: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    hidden: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    high: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    href: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    hrefLang: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    htmlFor: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    httpEquiv: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    id: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    inlist: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    inputMode: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    integrity: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    is: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    itemID: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    itemProp: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    itemRef: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    itemScope: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    itemType: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    keyParams: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    keyType: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    kind: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    label: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    lang: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    list: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    loop: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    low: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    manifest: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    marginHeight: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    marginWidth: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    max: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    maxLength: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    media: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    mediaGroup: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    method: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    min: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    minLength: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    multiple: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    muted: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    name: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    nonce: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    noValidate: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onAbort: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onAbortCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onAnimationEnd: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onAnimationEndCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onAnimationIteration: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onAnimationIterationCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onAnimationStart: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onAnimationStartCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onAuxClick: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onAuxClickCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onBeforeInput: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onBeforeInputCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onBlur: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onBlurCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onCanPlay: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onCanPlayCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onCanPlayThrough: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onCanPlayThroughCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onChange: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onChangeCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onClick: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onClickCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onCompositionEnd: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onCompositionEndCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onCompositionStart: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onCompositionStartCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onCompositionUpdate: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onCompositionUpdateCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onContextMenu: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onContextMenuCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onCopy: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onCopyCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onCut: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onCutCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onDoubleClick: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onDoubleClickCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onDrag: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onDragCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onDragEnd: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onDragEndCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onDragEnter: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onDragEnterCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onDragExit: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onDragExitCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onDragLeave: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onDragLeaveCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onDragOver: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onDragOverCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onDragStart: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onDragStartCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onDrop: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onDropCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onDurationChange: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onDurationChangeCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onEmptied: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onEmptiedCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onEncrypted: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onEncryptedCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onEnded: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onEndedCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onError: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onErrorCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onFocus: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onFocusCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onGotPointerCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onGotPointerCaptureCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onInput: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onInputCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onInvalid: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onInvalidCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onKeyDown: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onKeyDownCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onKeyPress: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onKeyPressCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onKeyUp: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onKeyUpCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onLoad: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onLoadCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onLoadedData: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onLoadedDataCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onLoadedMetadata: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onLoadedMetadataCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onLoadStart: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onLoadStartCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onLostPointerCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onLostPointerCaptureCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onMouseDown: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onMouseDownCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onMouseEnter: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onMouseLeave: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onMouseMove: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onMouseMoveCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onMouseOut: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onMouseOutCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onMouseOver: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onMouseOverCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onMouseUp: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onMouseUpCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onPaste: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onPasteCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onPause: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onPauseCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onPlay: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onPlayCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onPlaying: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onPlayingCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onPointerCancel: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onPointerCancelCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onPointerDown: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onPointerDownCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onPointerEnter: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onPointerEnterCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onPointerLeave: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onPointerLeaveCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onPointerMove: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onPointerMoveCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onPointerOut: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onPointerOutCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onPointerOver: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onPointerOverCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onPointerUp: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onPointerUpCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onProgress: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onProgressCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onRateChange: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onRateChangeCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onReset: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onResetCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onResize: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onResizeCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onScroll: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onScrollCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onSeeked: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onSeekedCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onSeeking: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onSeekingCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onSelect: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onSelectCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onStalled: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onStalledCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onSubmit: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onSubmitCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onSuspend: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onSuspendCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onTimeUpdate: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onTimeUpdateCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onTouchCancel: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onTouchCancelCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onTouchEnd: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onTouchEndCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onTouchMove: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onTouchMoveCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onTouchStart: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onTouchStartCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onTransitionEnd: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onTransitionEndCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onVolumeChange: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onVolumeChangeCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onWaiting: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onWaitingCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onWheel: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    onWheelCapture: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    open: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    optimum: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    pattern: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    placeholder: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    playsInline: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    poster: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    prefix: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    preload: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    property: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    radioGroup: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    readOnly: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    rel: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    rev: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    required: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    resource: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    results: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    reversed: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    role: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    rows: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    rowSpan: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    sandbox: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    scope: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    scoped: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    scrolling: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    seamless: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    security: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    selected: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    shape: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    size: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    sizes: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    slot: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    span: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    spellCheck: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    src: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    srcDoc: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    srcLang: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    srcSet: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    start: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    step: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    style: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    summary: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    suppressContentEditableWarning: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    suppressHydrationWarning: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    tabIndex: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    target: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    title: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    translate: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    type: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    typeof: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    unselectable: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    useMap: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    value: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    vocab: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    wmode: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    wrap: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-braillelabel': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-brailleroledescription': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-colindextext': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-description': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    'aria-rowindextext': import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    part: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
    exportparts: import("@elliemae/ds-props-helpers/dist/types/propTypes/types.js").ReactDescT;
};
