import type { ScaleBand, ScaleLinear, ScaleLogarithmic, ScaleTime } from 'd3';
import type { DSChartT } from '../react-desc-prop-types.js';
export declare const AXIS_TYPE: {
    readonly BAND: "BAND";
    readonly LINEAR: "LINEAR";
    readonly DATETIME: "DATETIME";
    readonly LOG: "LOG";
};
export declare class Scale {
    scale: ScaleBand<string> | ScaleLinear<number, number, never> | ScaleTime<number, number, never>;
    type: string;
    constructor(scale: ScaleBand<string> | ScaleLinear<number, number, never> | ScaleTime<number, number, never>);
    getBandwidth(): number;
}
export declare class BandScale extends Scale {
    type: keyof typeof AXIS_TYPE;
    scale: ScaleBand<string>;
    axisProps: DSChartT.AxisT;
    constructor(scale: ScaleBand<string>, axisProps: DSChartT.AxisT);
    get(value: string): number | undefined;
    getTicks(): string[];
    getTickFormatted(t: number | string | Date): string | number | Date;
    getTicksScaled(): number[];
    getBandwidth(): number;
}
export declare class LinearScale extends Scale {
    type: keyof typeof AXIS_TYPE;
    scale: ScaleLinear<number, number, never>;
    axisProps: DSChartT.AxisT;
    constructor(scale: ScaleLinear<number, number, never>, axisProps: DSChartT.AxisT);
    get(value: number): number;
    getTickFormatted(t: number | string | Date): string;
    getTicks(dimension: number): number[] | Date[];
    getTicksScaled(dimension: number): number[];
}
export declare class LogScale extends LinearScale {
    type: keyof typeof AXIS_TYPE;
    scale: ScaleLogarithmic<number, number, never>;
    axisProps: DSChartT.AxisT;
    constructor(scale: ScaleLogarithmic<number, number, never>, axisProps: DSChartT.AxisT);
    getTickFormatted(t: number | string | Date): string;
}
export declare class TimeLinearScale extends Scale {
    type: keyof typeof AXIS_TYPE;
    scale: ScaleTime<number, number, never>;
    axisProps: DSChartT.AxisT;
    constructor(scale: ScaleTime<number, number, never>, axisProps: DSChartT.AxisT);
    get(value: Date): number;
    getTickFormatted(t: number | string | Date): string;
    getTicks(dimension: number, intervalType?: string): (number | Date)[];
    getTicksScaled(dimension: number, intervalType?: string): number[];
}
export type ScaleT = BandScale | LinearScale | TimeLinearScale;
